declare type connection = {
    name: string;
    category: string;
    userId: string;
    phone: string;
    favorite: boolean;
    connectId: string;
    status: string;
};
declare type index = {
    key: number;
    fontColor: string;
    backgroundColor: string;
};
declare const _default: {
    /**
     * @function
     * @description Adding elements to an array
     * @param {array}
     * @returns {void}
     */
    add({ object, value }: {
        object: any[];
        value: any;
    }): void;
    /**
     * @function
     * @description Adds a record to the array at the specified subscript position
     * @param {array} object
     * @param {any} value
     * @param {string} index
     * @returns {void}
     */
    addByIndex({ object, value, index, }: {
        object: any[];
        value: any;
        index: string;
    }): void;
    /**
     * @function
     * @description Sorts the array according to the specified rule
     * @param {array} object
     * @param {any} iterate
     * @param {array} orders
     * @returns {array|string}}
     */
    SortBy({ object, iterate, orders, }: {
        object: any[];
        iterate: any;
        orders: any[];
    }): any[] | "object is not array";
    /**
     * @function
     * @description Empty array
     * @param {array} object
     * @returns {void}
     */
    clear({ object }: {
        object: any[];
    }): void;
    /**
     * @function
     * @description Find the attribute value corresponding to the key of
     * an item in the ARR, which is equal to the passed in key,
     * and delete it
     * @param {array} object
     * @param {string} key
     * @returns {void}
     */
    removeByKey({ object, key }: {
        object: {
            [x: string]: any;
        }[];
        key: string;
    }): void;
    /**
     * @function
     * @description If the attribute value of a key attribute in the
     * array object is equal to the passed in name or the attribute
     * value of the key attribute is empty, the item will be deleted;
     * otherwise, 'false' and 'color: Red' will be output
     * @param {array} object
     * @param {string} key
     * @param {string} name
     * @returns {void}
     */
    removeByName({ object, key, name, }: {
        object: {
            [x: string]: any;
        }[];
        key: string;
        name: string;
    }): void;
    /**
     * @function
     * @description Delete the item in the array equal to the value passed in
     * @param {array} object
     * @param {string} value
     * @returns {void}
     */
    removeByValue({ object, value, }: {
        object: number | string[];
        value: string | number;
    }): void;
    /**
     * @function
     * @description Delete the item in the object array equal to the value passed in.
     * @param {array} object
     * @param {string} value
     * @param {string} values
     * @returns {void}
     */
    removeObjectByValue({ object, values, value, }: {
        object: {}[];
        values: string;
        value: string;
    }): void;
    /**
     * @function
     * @description Find that the attribute value corresponding to the ID of an item
     * in the array is equal to the passed in ID, and delete the item
     * @param {array} object
     * @param {string} id
     * @returns {void}
     */
    removeById({ object, id }: {
        object: {
            [x: string]: any;
        }[];
        id: string;
    }): void;
    /**
     * object (Array|Object): The collection used for iteration.
     * index: one index of array
     * @function
     * @description Delete the index item of the array
     * @param {array} object
     * @param {number} index
     * @returns {void}
     */
    removeByIndex({ object, index }: {
        object: any[];
        index: number;
    }): void;
    /**
     * @description Find that the attribute value corresponding to the attribute
     * name index of an item in array object1 is equal to the passed in index value,
     * and the attribute value corresponding to the attribute name duration of the item is
     * equal to the passed in duration. Delete it from the array.
     * If the time of index item in array object2 is equal to duration, the index item
     * of array object2 will be deleted
     * @function
     * @param {array} object1
     * @param {array} object2
     * @param {string} duration
     * @param {number} index
     * @returns {void}
     */
    removeWeekByIndexs({ object1, object2, index, duration, }: {
        object1: {
            [x: string]: any;
        }[];
        object2: {
            [x: string]: any;
        }[];
        index: string | number;
        duration: string | number;
    }): void;
    /**
     *
     * @function
     * @description Recursively copies a value (which can be an object) and passes it into an array
     * @param {array} messages
     * @param {any} newMessage
     * @returns {void}
     */
    append({ newMessage, messages }: {
        newMessage: any;
        messages: any[];
    }): void;
    /**
     *
     * @function
     * @description Recursively copy a value into the array, invert the array and highlight the first item
     * @param {array} messages
     * @param {object} newMessage
     * @param {string} uniqueKey
     * @param {string} currentBackgroundColor
     * @param {string} backgroundColor
     * @param {string} fontColor
     * @param {string} currentFontColor
     * @returns {void}
     */
    appendUnique({ newMessage, messages, uniqueKey, currentBackgroundColor, backgroundColor, fontColor, currentFontColor, }: {
        newMessage: {
            [x: string]: any;
        };
        messages: any[];
        uniqueKey: string;
        currentBackgroundColor: string;
        backgroundColor: string;
        fontColor: string;
        currentFontColor: string;
    }): void;
    /**
     *
     * @function
     * @description Change the background color and font color of the trigger event.
     * @param {array} messages
     * @param {string} id
     * @param {string} currentBackgroundColor
     * @param {string} backgroundColor
     * @param {string} fontColor
     * @param {string} currentFontColor
     * @returns {void}
     */
    addColor({ messages, id, currentBackgroundColor, backgroundColor, fontColor, currentFontColor, }: {
        messages: any[];
        id: string;
        currentBackgroundColor: string;
        backgroundColor: string;
        fontColor: string;
        currentFontColor: string;
    }): void;
    /**
     *
     * @function
     * @description Determine whether there is value in the array
     * @param {array} object
     * @param {string} value
     * @returns {boolean}
     */
    has({ object, value }: {
        object: [];
        value: string | number;
    }): boolean;
    /**
     *
     * @function
     * @description Determine whether the array length is a certain value
     * @param {array} array
     * @param {number} len
     * @returns {boolean}
     */
    judgeListLength({ array, len }: {
        array: [];
        len: number;
    }): boolean;
    /**
     *
     * @function
     * @description Judge whether the value of the key attribute of an item in the array is equal to key
     * @param {array} object
     * @param {string} key
     * @returns {boolean}
     */
    hasKey({ object, key }: {
        object: {
            [x: string]: any;
        }[];
        key: string;
    }): boolean;
    /**
     *
     * @function
     * @description Spell the last four parameters into objects and add them to the array
     * @param {array} object
     * @param {string} key
     * @param {string} duration
     * @param {string} location
     * @param {string} index
     * @param {string} key
     * @returns {void}
     */
    AddWeek({ object, duration, location, index, key, }: {
        object: {
            [x: string]: any;
        }[];
        duration: string;
        location: string;
        index: string | number;
        key: string;
    }): void;
    /**
     *
     * @function
     * @description After a value is copied deeply, it is added to the array header
     * @param {array} messages
     * @param {any} newMessage
     * @returns {void|array}
     */
    push({ newMessage, messages }: {
        newMessage: any;
        messages: any[];
    }): any[] | undefined;
    pushAny({ newMessage, messages, }: {
        newMessage: any;
        messages: any[];
    }): any[];
    /**
     *
     * @function
     * @description Convert each item of the array into an object {key: 'xxx'} and put it in a new array
     * convert ["anemia", "anxiety", "arthritis"] to [{key: "anemia"},{key: "anxiety"},
     * {key: "arthritis"}] for listObject
     * @param {array} array
     * @returns {string|array}
     */
    covertToJsonArray({ array }: {
        array: any[];
    }): string | Record<string, any>;
    /**
     *
     * @function
     * @description get the length of array
     * @param {array} object
     * @returns {string}
     */
    getListLength({ object }: {
        object: any[];
    }): string;
    /**
     *
     * @function
     * @description Add an item with array1.key equal to the passed in value key to array2 through the passed in value key
     * @param {array} array1
     * @param {array} array2
     * @param {string} key
     * @returns {array}
     */
    copyByKey({ array1, array2, key, }: {
        array1: {
            [x: string]: any;
        }[];
        array2: {
            [x: string]: any;
        }[];
        key: any;
    }): {
        [x: string]: any;
    }[];
    /**
     *
     * @function
     * @description The passed in value is key. The value of the key attribute of
     * an item in the array is equal to the
     * passed in key value. Change the color attribute of this item
     * @param {array} array1
     * @param {string} value
     * @param {string} key
     * @returns {void}
     */
    changeColorByKey({ array, key, value, }: {
        array: {
            [x: string]: any;
        }[];
        key: any;
        value: any;
    }): void;
    /**
     *
     * @function
     * @description According to the passed in value key, put the value of an
     * item in the array whose key is equal to key into a new array and return
     * @param {array} array
     * @param {string} key
     * @returns {void | array}
     */
    convertToList({ array, key, }: {
        array: {
            [x: string]: any;
        }[];
        key: string;
    }): string[] | undefined;
    /**
     *
     * @function
     * @description According to the passed key1 and value values, if the key1 attribute of an item
     * in the array is equal to value, the attribute value corresponding to the key2 of the item is returned
     * @param {array} array
     * @param {string} value
     * @param {string} key1
     * @param {string} key2
     *
     * @returns {any}
     */
    getByKey({ array, key1, value, key2, }: {
        array: {
            [x: string]: any;
        }[];
        key1: string;
        value: any;
        key2: string;
    }): any;
    /**
     *
     * @function
     * @description Gets the subscript of an element of the array
     * @param {array} array
     * @param {string} key
     * @returns {number | void}
     */
    getIndex({ array, key }: {
        array: any[];
        key: any;
    }): number | undefined;
    /**
     *
     * @function
     * @description Gets an item in the object array and encapsulates it into an array to return
     * @param {array} array
     * @param {string} keyId
     * @returns {array | void}
     */
    getListByKey({ array, keyId, }: {
        array: {
            [x: string]: any;
        }[];
        keyId: string;
    }): any[] | undefined;
    /**
     *
     * @function
     * @description Get encapsulated connection
     * @param {array} array1
     * @param {array} array2
     * @returns {array}
     */
    getConnection({ array1, array2 }: {
        array1: any;
        array2: any;
    }): connection[];
    /**
     *
     * @function
     * @description If the favorite attribute value of an item in the array is true,
     * the item will be added to the result array
     * @param {array} object
     * @returns {array}
     */
    getFavorites({ object }: {
        object: {
            [x: string]: any;
        }[];
    }): any[];
    /**
     *
     * @function
     * @description Gets the first element of the array
     * @param {array} array
     * @returns {any}
     */
    getFirstItem({ array }: {
        array: any[];
    }): any;
    /**
     *
     * @function
     * @description Combine two arrays and sort
     * sortby: Select the character to sort
     * orders: Designated as "desc" in descending order, designated as "asc" in ascending order
     * @param {array} array2
     * @param {array} array1
     * @param {string} sortby
     * @param {string} orders
     * @returns {any}
     */
    concatArray({ array1, array2, sortby, orders, }: {
        array1: any[];
        array2: any[];
        sortby: any;
        orders: any;
    }): any[];
    /**
     *
     * @function
     * @description Determine whether the array has phonenumber
     * @param {array} array
     * @param {string} phoneNumber
     * @returns {boolean}
     */
    isExist({ array, phoneNumber, }: {
        array: {
            [x: string]: any;
        }[];
        phoneNumber: any;
    }): boolean;
    /**
     *
     * @function
     * @description Create the edge corresponding to the subtype according to the subtypelist array
     * @param {array} subtypelist
     * @param {array} createModel
     * @returns {void}
     */
    createBySubtype({ subtypelist, createModel, }: {
        subtypelist: any[];
        createModel: any;
    }): Promise<void>;
    /**
     *
     * @function
     * @description Convert the weekly time period in the original array into a string.
     * If it is empty, it is not settings
     * @param {array} planObject
     * @returns {array | void}
     */
    WeekSchedule({ planObject }: {
        planObject: any;
    }): Record<string, any> | undefined;
    /**
     *
     * @function
     * @description Splice two arrays
     * @param {array} array1
     * @param {array} array2
     * @returns {array | void}
     */
    concat({ array1, array2 }: {
        array1: any[];
        array2: any[];
    }): any[] | undefined;
    /**
     *
     * @function
     * @description Returns a bsig value based on the user name
     * @param {array} array
     * @param {string} userName
     * @returns {string | void}
     */
    getIdByUserName({ array, userName, }: {
        array: {
            [x: string]: any;
        }[];
        userName: AnalyserNode;
    }): string | undefined;
    /**
     * @function
     * @description According to the key as the attribute name, find the item
     * whose attribute value corresponding to the key value of an item in the
     * original array is equal to the attribute value corresponding to the key
     * value of an item in the subobject, and delete the item from the original array
     * @param {array} parentObject Remove elements from this object
     * @param {array} subObject Delete elements based on this object
     * @param {string} key Determine whether the key is duplicate
     * @returns {array | void}
     */
    removeByArray({ parentObject, subObject, key, }: {
        parentObject: {}[];
        subObject: {}[];
        key: string;
    }): {}[] | undefined;
    /**
     *
     * @function
     * @description If an object in the array has a key attribute and the attribute
     * exists on the instance, set the attribute value corresponding to the key
     * attribute of the item to flag
     * @param {array} object Modify the state of a field of this object
     * @param {string} key This is the field in the object, modify the state
     * @param {string} flag The state about to be modified true or false     true|false
     * @returns {void}
     *
     */
    toggleStatus({ object, key, flag, }: {
        object: {}[];
        key: string;
        flag: any;
    }): void;
    /**
    *
    * @function
    * @description If an object in the array has a key attribute and the attribute
    * exists on the instance, set the attribute value corresponding to the key
    * attribute of the item to flag
    * @param {array} object Modify the state of a field of this object
    * @param {string} key This is the field in the object, modify the state
    * @param {string} flag The state about to be modified true or false     true|false
    * @returns {void}
    *
    */
    toggleSelect({ object, key, value, newKey, flag, type, }: {
        object: {}[];
        key: string;
        value: string;
        newKey: string;
        flag: boolean;
        type: 'Radio' | 'Multi';
    }): void;
    /**
     * @function
     * @description To achieve paging effect, divide the array according to pagecount,
     * get the data, and then put it into a new array; After getting multiple such arrays,
     * put them into the result array
     * @param {array} array
     * @param {number} pageCount
     * @param {number} currentPage
     * @returns {array}
     */
    getPage({ array, pageCount, currentPage, }: {
        array: any[];
        pageCount: number;
        currentPage: number;
    }): any;
    /**
     * @function
     * @description Encapsulate the array through index
     * @param {array} array
     * @param {number} pageCount
     * @param {number} currentPage
     * @param {any|} select
     * @returns {array}
     */
    getPageIndex({ array, pageCount, currentPage, select, }: {
        array: any[];
        pageCount: number;
        currentPage: number;
        select: any;
    }): index[];
    elementUnique({ arr }: {
        arr: string[];
    }): string[];
    addProvider({ object, provider }: {
        object: any[];
        provider: {};
    }): void;
    /**
     * @function
     * @description According to the number and time of the current edge,
     * the increase or decrease of the current data is calculated under the corresponding
     * time span and corresponding time range
     * @param {array}  Object : Data to be processed
     * @param {number} timeLimit : Display the amount of data
     * @param {number} timeSpan : Process data based on month, week, and day
     * @param {string} increaseColor : Color when the rate of increase is positive
     * @param {string} decreaseColor : Color when the rate of increase is negative
     * @returns {array}
     */
    handleData({ Object, timeLimit, timeSpan, increaseColor, decreaseColor, }: {
        Object: any[];
        timeLimit: number;
        timeSpan: string;
        increaseColor: string;
        decreaseColor: string;
    }): {
        currentNum: any;
        currentRadio: any;
        radioString: any;
        color: any;
        data_x: Record<string, any>;
        data_y: Record<string, any>;
    } | undefined;
    /**
     * @function
     * @description If the length of the character array of all attributes
     * of an item in array object is 0, the item will be left blank.
     * @param {array} dayObject
     * @returns {void}
     */
    transformNull({ dayObject }: {
        dayObject: any[];
    }): void;
    /**
     * @function
     * @description Judge the number of elements in the array that are undefined,
     *  empty or 0 in length; If the number is greater than or equal to 7,
     * return true; otherwise, return false
     * @param {array} array
     * @returns {boolean}
     */
    isEmpty({ array }: {
        array: any[];
    }): boolean;
    /**
     * @function
     * @description Select the attribute values corresponding to the keys of all
     * items in the ARR and put them into the new array
     * @param {array} arr
     * @param {string} key
     * @returns {array}
     */
    selectOneToArr({ arr, key }: {
        arr: any[];
        key: string;
    }): any[];
    /**
     * @function
     * @description If the value corresponding to the key attribute of an item
     * in the array is equal to the value passed in, the value corresponding
     * to key1 of the item is returned
     * @param {array} arr
     * @param {string} key
     * @param {string} value
     * @param {string} key1
     * @returns {string}
     */
    matchInArray({ arr, value, key, key1, }: {
        arr: {}[];
        value: any;
        key: string;
        key1: string;
    }): any;
    /**
     * @function
     * @description Convert to a string and add parentheses
     * @param {any} arr
     * @returns {string}
     */
    toString({ arr }: {
        arr: any[];
    }): string;
    /**
     * @function
     * @description select key from array
     * @param {array} array
     * @param {string} path  path to key
     * @returns {array|void}
     */
    getKeyByArray({ array, path }: {
        array: any[];
        path: string;
    }): any[] | undefined;
    /**
     * @function
     * @description Query a key with the same value in the object array
     * ?Whether to consider multiple identical matches？
     * @param {array} array  => object array to select
     * @param {string} matchPath => path of matching key
     * @param {string} selectpath => path of selecting path
     * @param {string} value => match value
     * @returns {string}
     */
    SelectKeyByArray({ array, matchPath, selectpath, value, }: {
        array: any[];
        matchPath: string;
        selectpath: string;
        value: any;
    }): void;
    /**
     * @function
     * @description Add a deep clone to the array and return
     * @param {array} array
     * @returns {array}
     */
    addSelect({ array }: {
        array: any[];
    }): any[];
    /**
     * @function
     * @description Returns an object with the same value as value in the object array
     * @param {array} array
     * @param {string} key
     * @param {string} value
     * @returns {void}
     */
    getObjectByArray({ array, key, value, }: {
        array: {}[];
        key: string;
        value: any;
    }): {} | undefined;
    /**
     * @function
     * @description Query whether the array object exists in the object according to the array object and the incoming path.
     * If it exists, return true; otherwise, return false
     * @param {array} objArr
     * @param {string | number} values
     * @returns {boolean}
     */
    checkElememtExist({ objArr, values, }: {
        objArr: {}[];
        values: string | number;
    }): boolean;
    /**
     * @function
     * @description The original array is segmented according to the passed in number NumX,
     * and the numy item of the segmented array and the total segmented length are returned
     * according to the passed in number numy
     * @param {array} arrObj arrObj: array object
     * @param {number} numX numX: according this number splilt array
     * @param {number} numY numY: current page number
     * @returns
     */
    splitTableList({ arrObj, numX, numY, }: {
        arrObj: {
            [key: string]: {};
        }[];
        numX: number;
        numY: number;
    }): (number | (number | {
        [key: string]: {};
    })[])[];
    /**
     * @function
     * @description Determine whether the array is empty
     * @param {array} array
     * @returns {boolean}
     *
     */
    isArrayEmpty({ array }: {
        array: any[];
    }): boolean;
    /**
     * @function
     * @description Generate the corresponding page name according to the title of the doc
     * @param {array} array: Array to be processed
     * @param {string} type : 'Edit' | 'Review' | 'Preview'
     * @param {string} dataKey : path of key such as "name.title"
     * @returns array｜[]
     */
    transformPage({ array, type, dataKey, }: {
        array: any;
        type: 'Edit' | 'Review' | 'Preview';
        dataKey: string;
    }): any[];
    /**
     * @function
     * @description Converted to array to object array
     * @param {array} array
     * @returns {array}
     */
    transformArray({ array }: {
        array: any[];
    }): any;
    /**
     * @function
     * @description According to one of the passed in array objects and the corresponding path,
     * change the key value of an item of the object with the same attribute key value in
     * the other array to the passed in newvalue
     * @param {array} objArrOne
     * @param {array} objArrTwo
     * @param {string} strOnePath
     * @param {string} strTwoPath
     * @param {string} strValue
     * @param {any} newValue
     * @returns {array}
     */
    ComparisonSettingProperties({ objArrOne, strOnePath, objArrTwo, strTwoPath, strValue, newValue, status, }: {
        objArrOne: any[];
        strOnePath: string;
        objArrTwo: any[];
        strTwoPath: string;
        strValue: string | number;
        newValue?: any;
        status?: string | undefined;
    }): {}[];
    /**
     * @function
     * @description The passed in object array is de duplicated according to the path parameter
     * @param {array} objArr
     * @param {string} path
     * @returns {array}
     */
    uniqueByObjectKey({ objArr, path }: {
        objArr: {}[];
        path: string;
    }): {}[];
    /**
     *
     * @function
     * @description  stringArr include any item of array1, if include , return false, else return true
     * @param {array} stringArr
     * @returns  {boolean} true | false
     */
    allComplete(stringArr: string[]): boolean;
    /**
     *
     * @function
     * @description  For the incoming character array and character delimiter,
     * perform splicing processing, and return the processed results
     * @param {array} strArr
     * @param {string} sfill
     * @returns  {string}
     */
    formatStringFill({ strArr, sfill, }: {
        strArr: any;
        sfill: string;
    }): string;
    /**
     *
     * @function
     * @description  According to the passed in array object, compare whether the value
     * corresponding to the key is equal to the passed in value. If yes, return true,
     * and if no, return false
     * @param {array} arrObject
     * @param {any} value
     * @param {string} keyAtl
     * @returns  {boolean}
     */
    findSelectAtl({ arrObject, value, keyAtl, }: {
        arrObject: object[];
        value: any;
        keyAtl: string;
    }): boolean;
    /**
     *
     * @function
     * @description  The passed in array is filtered by tags
     * @param {array} sourceDoc
     * @param {string} tagCategory
     * @param {string} tagName
     * @returns  {array}
     */
    filterByTag({ sourceDoc, tagCategory, tagName, }: {
        sourceDoc: object[];
        tagCategory: string;
        tagName: string;
    }): any[];
    /**
     *
     * @function
     * @description  Some attribute values when initializing the meeting, such as boxshadow and bordercolor
     * @param {array} sourceEdgeList
     * @returns  {array}
     */
    initMeetingStyle({ sourceEdgeList }: {
        sourceEdgeList: any[];
    }): any[];
    /**
     *
     * @function
     * @description  Filter the array by passing in the path
     * @param {array} objArr
     * @param {string} path
     * @param {string[]} compareStr
     * @returns  {array}
     */
    filterArrayByPath({ objArr, path, compareStr, }: {
        objArr: any[];
        path: string;
        compareStr: string[];
    }): {
        [x: string]: any;
    }[];
    /**
     *
     * @function
     * @description  Compare the passed key1 value with value, and then return the value under the key2 path
     * @param {array} array
     * @param {string} key1
     * @param {string} value
     * @param {string} key2
     * @returns  {string}
     */
    getValueByKey({ array, key1, value, key2, }: {
        array: {}[];
        key1: string;
        value: string;
        key2: string;
    }): any;
    /**
     *
     * @function
     * @description  Judge whether value is odd or even according to the passed in object array and path, and add 1 to the even number
     * @param {array} objArr
     * @param {string} path
     * @returns  {array}
     */
    checkType({ objArr, path }: {
        objArr: {}[];
        path: string;
    }): {}[];
    /**
     *
     * @function
     * @description  Get the information of the selected time and encapsulate the bit group to return
     * @param {array} objArr
     * @param {number} index
     * @param {string} strPath
     * @param {string} key
     * @param {string} location
     * @returns  {array}
     */
    addWeekDuration({ objArr, index, strPath, key, location, }: {
        objArr: {}[];
        index: number;
        strPath: string;
        key: string;
        location: string;
    }): {}[];
    /**
     *
     * @function
     * @description  remove Value In Double List
     * @param {array} objArr
     * @param {number | string} value
     * @param {string} key
     * @param {array} objArr1
     * @returns  {undefined}
     */
    removeValueInDoubleList({ objArr, value, key, objArr1, index, }: {
        objArr: any[];
        value: string | number;
        key: string;
        objArr1: any[];
        index: number;
    }): void;
    /**
     *
     * @function
     * @description  Format date and time
     * @param {array} arr
     * @param {string} indexParam
     * @param {string} keyParam
     * @param {string} strParam
     * @returns  {array}
     */
    formaDuration({ arr, indexParam, keyParam, strParam, }: {
        arr: ((string | number)[] | object)[];
        indexParam: string;
        keyParam: string;
        strParam: string;
    }): {}[];
    /**
     * @description trans old patient profile structure to new structure
     * @param {object} objArr
     * @returns {object}
     */
    formatProfile({ objArr }: {
        objArr: {
            [x: string]: any;
        }[];
    }): {
        [x: string]: any;
    }[];
    /**
     * @description set Property Interlaced Change
     * @param {object[]} arrIn
     * @param {string[]} arr
     * @param {string[]} valueArr
     * @param {string[]} errorArr
     * @returns {object[]}
     */
    setPropertyInterlacedChange({ arrIn, arr, valueArr, errorArr, }: {
        arrIn: {
            [key: string]: any;
        }[];
        arr: string[];
        valueArr: string[];
        errorArr: string[];
    }): {
        [key: string]: any;
    }[];
    /**
     * @description set Form Jump Page
     * @param {any[]} objArry
     * @param {any} docFormObj
     * @returns {any[]}
     */
    setFormJumpPage({ objArry, docFormObj, }: {
        objArry: any[];
        docFormObj: any;
    }): any[];
    /**
     * @description Sorts the given array
     * @param {any[]} arr
     * @returns {any[]|string}
     */
    sortArray({ arr }: {
        arr: any[];
    }): any[] | "arr is not array";
    /**
     * @description Divide and form new objects according to object attributes
     * @param {string[]} arr
     * @param {string} split
     * @returns {{}[]}
     */
    splitArrString({ arr, split, }: {
        arr: string[];
        split: string;
    }): {
        [x: string]: any;
    }[];
    /**
     * @description Keep filtering the latest documents
     * @param {object[]} docList
     * @param {string} path
     * @returns {object[]}
     */
    keepLatestDoc({ docList, path, }: {
        docList: {
            [x: string]: any;
        }[];
        path: string;
    }): {
        [x: string]: any;
    }[];
    /**
     * @description Set current meeting status
     * @param {object[]} object
     * @param {string} type
     * @param {string} tage
     * @returns {object[]}
     */
    setMeetingStatus({ object, type, tage, }: {
        object: {
            [x: string]: any;
        }[];
        type?: string | undefined;
        tage?: string | undefined;
    }): {
        [x: string]: any;
    }[];
    /**
     * @description Set current meeting status
     * @param {array} array
     * @param {number} len
     * @returns {boolean}
     */
    judgeArr({ array, len }: {
        array: [];
        len: number;
    }): boolean;
    /**
     * @description Change item list
     * @param {object[]} array
     * @param {string} path
     * @param {object} obj
     * @returns {undefined}
     */
    ChangeAnItemInArray({ array, path, obj, }: {
        array: {}[];
        path: string;
        obj: {};
    }): void;
    /**
     * @description Gets the in the array
     * @param {any[]} dataArray
     * @param {number} index
     * @returns {any}
     */
    GetSomeData({ dataArray, index, }: {
        dataArray: {
            [x: string]: any;
        }[];
        index?: number | undefined;
    }): {} | undefined;
    /**
     * @description Delete array items that do not meet the criteria
     * @param {object[]} docs
     * @param {number} local
     * @param {number} binary
     * @returns {object[]}
     */
    arrTageTypeIsValid({ docs, local, binary, }: {
        docs: {}[];
        local: number;
        binary: number;
    }): {}[];
    /**
     * @function
     * @description Judgment key and return value
     * @param {Array} objArr
     * @param {string} pathKey
     * @param {string} pathValue
     * @param {string[]} valueArr
     * @returns {string[]}
     */
    judgeKeyAndReturnValue({ objArr, pathKey, pathValue, valueArr }: {
        objArr: {
            [x: string]: any;
        }[];
        pathKey: string;
        pathValue: string;
        valueArr: string[];
    }): string[];
    /**
     * @function
     * @description Format String Fill
     * @param {any} objArr
     * @param {string} sfill
     * @returns {string}
     */
    objArrFormatStringFill({ objArr, sfill, }: {
        objArr: any;
        sfill: string;
    }): string;
    /**
     * @function
     * @description get the Specified Object
     * @param {object[]} objArr
     * @param {string} path
     * @param {string|number|boolean} value
     * @returns {object[]}
     */
    getSpecifiedObject({ objArr, path, value, }: {
        objArr: any[];
        path: string;
        value: string | number | boolean;
    }): {
        [x: string]: any;
    }[];
    /**
     * @function
     * @description get the value in the array
     * @param {object[]} objectArr
     * @param {string} keyOne
     * @param {string} keyTwo
     * @param {string|number|boolean} valueOne
     * @param {string|number|boolean} valueTwo
     * @returns {object[]}
     */
    setObjectByKey({ objectArr, keyOne, keyTwo, valueOne, valueTwo }: {
        objectArr: {}[];
        keyOne: string;
        keyTwo: string;
        valueOne: any;
        valueTwo: any;
    }): {}[];
    /**
     * @function
     * @description recoverModifiers
     * @param {array} array
     * @returns {object[]}
     */
    recoverModifiers({ array }: {
        array: any;
    }): any[];
    /**
     * @function
     * @description Match the parent folder with the child folder
     * @param {array} parentFiles
     * @param {array} childFiles
     * @returns {object[]}
     */
    folderMatching({ parentFiles, childFiles }: {
        parentFiles: {
            [x: string]: any;
        }[];
        childFiles: {
            [x: string]: any;
        }[];
    }): {
        [x: string]: any;
    }[];
    /**
       * @function
       * @description Determine whether the object exists in an array object
       * @param {object[]} object
       * @param {any} value
       * @param {string} key
       * @returns {boolean}
       */
    containingValue({ object, value, key }: {
        object: object[];
        value: any;
        key: string;
    }): boolean;
    setList({ arr, level, title }: {
        arr: {
            [x: string]: any;
        }[];
        level: number;
        title: string;
    }): {
        [x: string]: any;
    }[];
    extractWithType({ docList, type }: {
        docList: {
            [x: string]: any;
        }[];
        type: number;
    }): any[];
    getOrReplaceAnArrayItem({ strArr, tag, index, value, }: {
        strArr: string[];
        tag: boolean;
        index?: any;
        value?: any;
    }): string[] | string;
};
export default _default;
