export { builtIn };
declare function builtIn({ pageName, apiObject, dispatch }: {
    pageName: any;
    apiObject: any;
    dispatch: any;
}): (input?: any) => Promise<any>;
/**
 * @param dispatch Function to change the state.
 * @returns Object of builtIn functions.
 */
export default function builtInFns(args?: {
    dispatch?: Function;
    processPopulate?: Function;
    getPage?: Function;
    emit?: Function;
    /**
     * Elastic search client
     *
     * See https://github.com/elastic/bower-elasticsearch-js/blob/master/elasticsearch.js
     */
    SearchClient?: InstanceType<any>;
}): {
    string: {
        formatTimer(time: number, type?: string): string;
        formatUnixtimeSecond(unixTime: number): string;
        formatNowTime(): string;
        formatUnixtime_en(unixTime: string | number): any;
        formatUnixtimeL_en(unixTime: number): string;
        formatUnixtimeLT_en(unixTime: number): string;
        formatDurationInSecond(unixTime: number): any;
        formatDurationInMicroSecond(unixTime: number): string;
        concat(stringArr: string[]): string;
        concatTrim(strValue: string[]): string;
        split16DkeytoArray(key: string): string[];
        split16Dkey(Dkey: string): string;
        equal({ string1, string2 }: {
            string1: string;
            string2: string;
        }): boolean;
        getFirstChar({ value }: {
            value: string;
        }): string | void;
        getLength(str: any): number;
        retainNumber({ value }: {
            value: string;
        }): number;
        phoneVerification({ countryCode, phoneNumber }: {
            countryCode: string;
            phoneNumber: string | number;
        }): boolean;
        phoneNumberSplit({ phoneNumber, sign }: {
            phoneNumber: number;
            sign: string;
        }): import("immer/dist/internal").AnyArray;
        judgeMultipleEqual(stringArr: string[]): boolean;
        judgeSelectTime(stringArr: string[]): boolean;
        judgeFillinAll(stringArr: string[]): boolean;
        judgeIsAllEmpty(stringArr: string[]): boolean;
        judgeAllTrue({ str1, str2, str3 }: {
            str1: string;
            str2: string;
            str3: string;
        }): string;
        judgesFillinAll(object: any): boolean;
        strLenx({ obj }: {
            obj: {};
        }): string;
        distanceByPosition(point: any): string | undefined;
        getAddress({ object }: {
            object: {
                [x: string]: any;
            };
        }): {
            address: string;
            city: string;
            state: string;
            zipCode: string;
            location: string;
            geoCode: never[];
            country: string;
            county: string;
            firsLine: string;
            SecondLine: string;
            distance: string;
        };
        generateID({ facilityID, locationID, roomID }: {
            facilityID: string;
            locationID: string;
            roomID: string | number;
        }): string;
        bitFormatting(bitNum: number): string;
        equalsLenString({ stringOne, stringTwo, len }: {
            stringOne: string;
            stringTwo: string;
            len: number;
        }): boolean;
        dollarFormat(fund: any): any;
        parseSpliceString({ value, objArr, path, pathItem }: {
            value: string | number;
            objArr: {
                [x: string]: any;
            }[];
            path?: string | undefined;
            pathItem?: string | undefined;
        }): string;
        addValue({ value1, value2 }: {
            value1: any;
            value2: any;
        }): any;
    };
    eccNaCl: {
        signature({ message, eskSign, sk }: {
            message: any;
            eskSign: any;
            sk: any;
        }): string;
        verifySignature(signature: string, pkSign: string): boolean;
        generate16Dkey(): string;
        decryptAES({ key, message }: {
            key: any;
            message: any;
        }): any;
        encryptAES({ key, message }: {
            key: any;
            message: any;
        }): any;
        decryptASK({ sendPk, recvSk, eData }: {
            sendPk: any;
            recvSk: any;
            eData: any;
        }): string | null;
        encryptASK({ recvPk, sendSk, data }: {
            recvPk: any;
            sendSk: any;
            data: any;
        }): string;
        skCheck({ pk, sk }: {
            pk: any;
            sk: any;
        }): any;
        generateESAK({ pk }: {
            pk: string;
        }): string;
        decryptData({ esak, publicKey, secretKey, data, }: {
            esak: string | Uint8Array;
            publicKey: string;
            secretKey: string;
            data: Uint8Array;
        }): Uint8Array;
        decryptESAK({ esak, publicKey, secretKey, }: {
            esak: string | Uint8Array;
            publicKey: string;
            secretKey: string;
        }): string;
        isEdgeEncrypted({ id }: {
            id: string;
        }): Promise<boolean>;
        getSAKFromEdge({ id }: {
            id: string;
        }): Promise<string>;
    };
    object: {
        remove({ object, key }: {
            object: {};
            key: string;
        }): void;
        clear({ object, key }: {
            object: {};
            key: string;
        }): void;
        set({ object, key, value }: {
            object: {};
            key: string;
            value: any;
        }): void;
        setObjectKey({ objectArr, key, value, }: {
            objectArr: {}[];
            key: string;
            value: any;
        }): {}[];
        get({ object, key }: {
            object: {};
            key: string;
        }): any;
        has({ object, key }: {
            object: {};
            key: string;
        }): boolean | undefined;
        objectHasValue({ objArr, valPath, }: {
            objArr: {
                [key: string]: {};
            }[];
            valPath: string;
        }): boolean;
        clearAndSetKey({ object, item, key, value, }: {
            object: {
                [x: string]: any;
            }[];
            item: {};
            key: string;
            value: any;
        }): void;
        extract({ array, field }: {
            array: any[];
            field: string;
        }): any[];
        extractArray({ obj, arr }: {
            obj: any[];
            arr: any[];
        }): any[] | "";
        authToSubType({ auth, authList, }: {
            auth: {
                [x: string]: any;
            };
            authList: {
                [x: string]: any;
            };
        }): number[];
        findTrue({ object }: {
            object: {
                [x: string]: any;
            };
        }): {
            Settings: boolean;
            UserManagement: boolean;
            Schedule: boolean;
        };
        setAuthAllTrue({ object }: {
            object: {
                [x: string]: any;
            };
        }): {
            [x: string]: any;
        };
        isEmpty({ object }: {
            object: any;
        }): boolean;
        setByKey({ object, key, value, }: {
            object: {
                [x: string]: any;
            };
            key: any;
            value: any;
        }): void;
        getObjValueAndKey({ objects, objStr, }: {
            objects: {
                [x: string]: any;
            };
            objStr: any;
        }): Object;
        getObjKey({ objects, }: {
            objects: {
                [x: string]: any;
            };
        }): string[] | null;
        getObjWithKV({ object }: {
            object: any[];
        }): {
            key: string;
            value: string;
        }[];
        setProperty({ obj, label, text, arr, valueArr, errorArr, }: {
            obj: {
                [key: string]: any;
            }[];
            label: string;
            text: string;
            arr: string[];
            valueArr: string[];
            errorArr: string[];
        }): {
            [key: string]: any;
        }[];
        setTimeProperty({ obj }: {
            obj: {
                [key: string]: any;
            }[];
        }): any;
        clearAll({ object }: {
            object: {
                [x: string]: any;
            };
        }): void;
        extractingFeatureStrings({ objArrs, pathObj, bool, }: {
            objArrs: {}[];
            pathObj: string[];
            bool?: boolean | undefined;
        }): string | {
            [key: string]: string[];
        }[];
        addKey({ object, key, value }: {
            object: {}[];
            key: string;
            value: any;
        }): {}[];
        deleteKey({ object, path }: {
            object: {};
            path: string[];
        }): {};
        hasMultipleKeys({ object, keyArr }: {
            object: {};
            keyArr: string[];
        }): boolean;
        transformStatus(object: {
            [x: string]: any;
        }, type?: string, state?: string): string;
        judgeAllTrue({ object }: {
            object: {
                [x: string]: any;
            };
        }): boolean;
        setMultipleProperty({ obj, label, checkValue, arr, valueArr, errorArr, }: {
            obj: {
                [key: string]: any;
            }[];
            label: string;
            checkValue: any;
            arr: string[];
            valueArr: string[];
            errorArr: string[];
        }): any;
        eEncapsulatedObj({ originalObjArr, pathArr }: {
            originalObjArr: {
                [x: string]: any;
            }[];
            pathArr: string[];
        }): {
            [x: string]: any;
        }[];
        toCsvFormat({ arrObj }: {
            arrObj: {
                [x: string]: any;
            };
        }): string | {
            [x: string]: any;
        };
        matchSearchValue({ objArr, paths, value }: {
            objArr: {
                [x: string]: any;
            }[];
            paths: string[];
            value: string | number;
        }): {
            [x: string]: any;
        }[];
        clearObject({ obj }: {
            obj: object;
        }): void;
        difference({ object, baseObject }: {
            object: {
                [x: string]: any;
            };
            baseObject: {
                [x: string]: any;
            };
        }): {
            [x: string]: any;
        };
        modifyObjectProperties({ obj, keyArr, bool }: {
            obj: object;
            keyArr: string[];
            bool: boolean;
        }): any;
        setObjDisplayAndColor({ obj }: {
            obj: object;
        }): object;
    };
    array: {
        add({ object, value }: {
            object: any[];
            value: any;
        }): void;
        addByIndex({ object, value, index, }: {
            object: any[];
            value: any;
            index: string;
        }): void;
        SortBy({ object, iterate, orders, }: {
            object: any[];
            iterate: any;
            orders: any[];
        }): any[] | "object is not array";
        clear({ object }: {
            object: any[];
        }): void;
        removeByKey({ object, key }: {
            object: {
                [x: string]: any;
            }[];
            key: string;
        }): void;
        removeByName({ object, key, name, }: {
            object: {
                [x: string]: any;
            }[];
            key: string;
            name: string;
        }): void;
        removeByValue({ object, value, }: {
            object: number | string[];
            value: string | number;
        }): void;
        removeObjectByValue({ object, values, value, }: {
            object: {}[];
            values: string;
            value: string;
        }): void;
        removeById({ object, id }: {
            object: {
                [x: string]: any;
            }[];
            id: string;
        }): void;
        removeByIndex({ object, index }: {
            object: any[];
            index: number;
        }): void;
        removeWeekByIndexs({ object1, object2, index, duration, }: {
            object1: {
                [x: string]: any;
            }[];
            object2: {
                [x: string]: any;
            }[];
            index: string | number;
            duration: string | number;
        }): void;
        append({ newMessage, messages }: {
            newMessage: any;
            messages: any[];
        }): void;
        appendUnique({ newMessage, messages, uniqueKey, currentBackgroundColor, backgroundColor, fontColor, currentFontColor, }: {
            newMessage: {
                [x: string]: any;
            };
            messages: any[];
            uniqueKey: string;
            currentBackgroundColor: string;
            backgroundColor: string;
            fontColor: string;
            currentFontColor: string;
        }): void;
        addColor({ messages, id, currentBackgroundColor, backgroundColor, fontColor, currentFontColor, }: {
            messages: any[];
            id: string;
            currentBackgroundColor: string;
            backgroundColor: string;
            fontColor: string;
            currentFontColor: string;
        }): void;
        has({ object, value }: {
            object: [];
            value: string | number;
        }): boolean;
        judgeListLength({ array, len }: {
            array: [];
            len: number;
        }): boolean;
        hasKey({ object, key }: {
            object: {
                [x: string]: any;
            }[];
            key: string;
        }): boolean;
        AddWeek({ object, duration, location, index, key, }: {
            object: {
                [x: string]: any;
            }[];
            duration: string;
            location: string;
            index: string | number;
            key: string;
        }): void;
        push({ newMessage, messages }: {
            newMessage: any;
            messages: any[];
        }): any[] | undefined;
        pushAny({ newMessage, messages, }: {
            newMessage: any;
            messages: any[];
        }): any[];
        covertToJsonArray({ array }: {
            array: any[];
        }): string | Record<string, any>;
        getListLength({ object }: {
            object: any[];
        }): string;
        copyByKey({ array1, array2, key, }: {
            array1: {
                [x: string]: any;
            }[];
            array2: {
                [x: string]: any;
            }[];
            key: any;
        }): {
            [x: string]: any;
        }[];
        changeColorByKey({ array, key, value, }: {
            array: {
                [x: string]: any;
            }[];
            key: any;
            value: any;
        }): void;
        convertToList({ array, key, }: {
            array: {
                [x: string]: any;
            }[];
            key: string;
        }): string[] | undefined;
        getByKey({ array, key1, value, key2, }: {
            array: {
                [x: string]: any;
            }[];
            key1: string;
            value: any;
            key2: string;
        }): any;
        getIndex({ array, key }: {
            array: any[];
            key: any;
        }): number | undefined;
        getListByKey({ array, keyId, }: {
            array: {
                [x: string]: any;
            }[];
            keyId: string;
        }): any[] | undefined;
        getConnection({ array1, array2 }: {
            array1: any;
            array2: any;
        }): {
            name: string;
            category: string;
            userId: string;
            phone: string;
            favorite: boolean;
            connectId: string;
            status: string;
        }[];
        getFavorites({ object }: {
            object: {
                [x: string]: any;
            }[];
        }): any[];
        getFirstItem({ array }: {
            array: any[];
        }): any;
        concatArray({ array1, array2, sortby, orders, }: {
            array1: any[];
            array2: any[];
            sortby: any;
            orders: any;
        }): any[];
        isExist({ array, phoneNumber, }: {
            array: {
                [x: string]: any;
            }[];
            phoneNumber: any;
        }): boolean;
        createBySubtype({ subtypelist, createModel, }: {
            subtypelist: any[];
            createModel: any;
        }): Promise<void>;
        WeekSchedule({ planObject }: {
            planObject: any;
        }): Record<string, any> | undefined;
        concat({ array1, array2 }: {
            array1: any[];
            array2: any[];
        }): any[] | undefined;
        getIdByUserName({ array, userName, }: {
            array: {
                [x: string]: any;
            }[];
            userName: AnalyserNode;
        }): string | undefined;
        removeByArray({ parentObject, subObject, key, }: {
            parentObject: {}[];
            subObject: {}[];
            key: string;
        }): {}[] | undefined;
        toggleStatus({ object, key, flag, }: {
            object: {}[];
            key: string;
            flag: any;
        }): void;
        toggleSelect({ object, key, value, newKey, flag, type, }: {
            object: {}[];
            key: string;
            value: string;
            newKey: string;
            flag: boolean;
            type: "Radio" | "Multi";
        }): void;
        getPage({ array, pageCount, currentPage, }: {
            array: any[];
            pageCount: number;
            currentPage: number;
        }): any;
        getPageIndex({ array, pageCount, currentPage, select, }: {
            array: any[];
            pageCount: number;
            currentPage: number;
            select: any;
        }): {
            key: number;
            fontColor: string;
            backgroundColor: string;
        }[];
        elementUnique({ arr }: {
            arr: string[];
        }): string[];
        addProvider({ object, provider }: {
            object: any[];
            provider: {};
        }): void;
        handleData({ Object, timeLimit, timeSpan, increaseColor, decreaseColor, }: {
            Object: any[];
            timeLimit: number;
            timeSpan: string;
            increaseColor: string;
            decreaseColor: string;
        }): {
            currentNum: any;
            currentRadio: any;
            radioString: any;
            color: any;
            data_x: Record<string, any>;
            data_y: Record<string, any>;
        } | undefined;
        transformNull({ dayObject }: {
            dayObject: any[];
        }): void;
        isEmpty({ array }: {
            array: any[];
        }): boolean;
        selectOneToArr({ arr, key }: {
            arr: any[];
            key: string;
        }): any[];
        matchInArray({ arr, value, key, key1, }: {
            arr: {}[];
            value: any;
            key: string;
            key1: string;
        }): any;
        toString({ arr }: {
            arr: any[];
        }): string;
        getKeyByArray({ array, path }: {
            array: any[];
            path: string;
        }): any[] | undefined;
        SelectKeyByArray({ array, matchPath, selectpath, value, }: {
            array: any[];
            matchPath: string;
            selectpath: string;
            value: any;
        }): void;
        addSelect({ array }: {
            array: any[];
        }): any[];
        getObjectByArray({ array, key, value, }: {
            array: {}[];
            key: string;
            value: any;
        }): {} | undefined;
        checkElememtExist({ objArr, values, }: {
            objArr: {}[];
            values: string | number;
        }): boolean;
        splitTableList({ arrObj, numX, numY, }: {
            arrObj: {
                [key: string]: {};
            }[];
            numX: number;
            numY: number;
        }): (number | (number | {
            [key: string]: {};
        })[])[];
        isArrayEmpty({ array }: {
            array: any[];
        }): boolean;
        transformPage({ array, type, dataKey, }: {
            array: any;
            type: "Edit" | "Review" | "Preview";
            dataKey: string;
        }): any[];
        transformArray({ array }: {
            array: any[];
        }): any;
        ComparisonSettingProperties({ objArrOne, strOnePath, objArrTwo, strTwoPath, strValue, newValue, status, }: {
            objArrOne: any[];
            strOnePath: string;
            objArrTwo: any[];
            strTwoPath: string;
            strValue: string | number;
            newValue?: any;
            status?: string | undefined;
        }): {}[];
        uniqueByObjectKey({ objArr, path }: {
            objArr: {}[];
            path: string;
        }): {}[];
        allComplete(stringArr: string[]): boolean;
        formatStringFill({ strArr, sfill, }: {
            strArr: any;
            sfill: string;
        }): string;
        findSelectAtl({ arrObject, value, keyAtl, }: {
            arrObject: object[];
            value: any;
            keyAtl: string;
        }): boolean;
        filterByTag({ sourceDoc, tagCategory, tagName, }: {
            sourceDoc: object[];
            tagCategory: string;
            tagName: string;
        }): any[];
        initMeetingStyle({ sourceEdgeList }: {
            sourceEdgeList: any[];
        }): any[];
        filterArrayByPath({ objArr, path, compareStr, }: {
            objArr: any[];
            path: string;
            compareStr: string[];
        }): {
            [x: string]: any;
        }[];
        getValueByKey({ array, key1, value, key2, }: {
            array: {}[];
            key1: string;
            value: string;
            key2: string;
        }): any;
        checkType({ objArr, path }: {
            objArr: {}[];
            path: string;
        }): {}[];
        addWeekDuration({ objArr, index, strPath, key, location, }: {
            objArr: {}[];
            index: number;
            strPath: string;
            key: string;
            location: string;
        }): {}[];
        removeValueInDoubleList({ objArr, value, key, objArr1, index, }: {
            objArr: any[];
            value: string | number;
            key: string;
            objArr1: any[];
            index: number;
        }): void;
        formaDuration({ arr, indexParam, keyParam, strParam, }: {
            arr: (object | (string | number)[])[];
            indexParam: string;
            keyParam: string;
            strParam: string;
        }): {}[];
        formatProfile({ objArr }: {
            objArr: {
                [x: string]: any;
            }[];
        }): {
            [x: string]: any;
        }[];
        setPropertyInterlacedChange({ arrIn, arr, valueArr, errorArr, }: {
            arrIn: {
                [key: string]: any;
            }[];
            arr: string[];
            valueArr: string[];
            errorArr: string[];
        }): {
            [key: string]: any;
        }[];
        setFormJumpPage({ objArry, docFormObj, }: {
            objArry: any[];
            docFormObj: any;
        }): any[];
        sortArray({ arr }: {
            arr: any[];
        }): any[] | "arr is not array";
        splitArrString({ arr, split, }: {
            arr: string[];
            split: string;
        }): {
            [x: string]: any;
        }[];
        keepLatestDoc({ docList, path, }: {
            docList: {
                [x: string]: any;
            }[];
            path: string;
        }): {
            [x: string]: any;
        }[];
        setMeetingStatus({ object, type, tage, }: {
            object: {
                [x: string]: any;
            }[];
            type?: string | undefined;
            tage?: string | undefined;
        }): {
            [x: string]: any;
        }[];
        judgeArr({ array, len }: {
            array: [];
            len: number;
        }): boolean;
        ChangeAnItemInArray({ array, path, obj, }: {
            array: {}[];
            path: string;
            obj: {};
        }): void;
        GetSomeData({ dataArray, index, }: {
            dataArray: {
                [x: string]: any;
            }[];
            index?: number | undefined;
        }): {} | undefined;
        arrTageTypeIsValid({ docs, local, binary, }: {
            docs: {}[];
            local: number;
            binary: number;
        }): {}[];
        judgeKeyAndReturnValue({ objArr, pathKey, pathValue, valueArr }: {
            objArr: {
                [x: string]: any;
            }[];
            pathKey: string;
            pathValue: string;
            valueArr: string[];
        }): string[];
        objArrFormatStringFill({ objArr, sfill, }: {
            objArr: any;
            sfill: string;
        }): string;
        getSpecifiedObject({ objArr, path, value, }: {
            objArr: any[];
            path: string;
            value: string | number | boolean;
        }): {
            [x: string]: any;
        }[];
        setObjectByKey({ objectArr, keyOne, keyTwo, valueOne, valueTwo }: {
            objectArr: {}[];
            keyOne: string;
            keyTwo: string;
            valueOne: any;
            valueTwo: any;
        }): {}[];
        recoverModifiers({ array }: {
            array: any;
        }): any[];
        folderMatching({ parentFiles, childFiles }: {
            parentFiles: {
                [x: string]: any;
            }[];
            childFiles: {
                [x: string]: any;
            }[];
        }): {
            [x: string]: any;
        }[];
        containingValue({ object, value, key }: {
            object: object[];
            value: any;
            key: string;
        }): boolean;
        setList({ arr, level, title }: {
            arr: {
                [x: string]: any;
            }[];
            level: number;
            title: string;
        }): {
            [x: string]: any;
        }[];
        extractWithType({ docList, type }: {
            docList: {
                [x: string]: any;
            }[];
            type: number;
        }): any[];
        getOrReplaceAnArrayItem({ strArr, tag, index, value, }: {
            strArr: string[];
            tag: boolean;
            index?: any;
            value?: any;
        }): string | string[];
    };
    number: {
        inRange({ number, start, end, }: {
            number: number;
            start: number;
            end: number;
        }): boolean;
        multiply({ number, multiple }: {
            number: number;
            multiple: number;
        }): number;
        OctToBin({ number }: {
            number: number;
        }): string | 0;
        getAuthority({ authSubtype, authList, }: {
            authSubtype: any[];
            authList: {};
        }): any;
        addition({ num, step }: {
            num: any;
            step: any;
        }): any;
        Subtraction({ num, step }: {
            num: any;
            step: any;
        }): number;
        less({ num1, num2 }: {
            num1: number;
            num2: number;
        }): boolean;
        inhx({ intHex, index, hex, }: {
            intHex: number;
            index: number;
            hex: number;
        }): number;
        hexAnd({ intOne, hexTwo }: {
            intOne: number;
            hexTwo: number;
        }): number;
        hexOr({ intOne, hexTwo }: {
            intOne: number;
            hexTwo: number;
        }): number;
        hx({ docGroup, localArr, binaryArr, }: {
            docGroup: any[];
            localArr: number[];
            binaryArr: number[];
        }): false | number[];
        typeIsValid({ docType, localArr, binaryArr, }: {
            docType: number;
            localArr: number[];
            binaryArr: number[];
        }): boolean;
        formValid({ docData }: {
            docData: {};
        }): boolean;
        transformSubtype({ subtype, addition }: {
            subtype: any;
            addition: number;
        }): number;
        judgeNumber({ num }: {
            num: any;
        }): boolean;
        pagingFax({ value1, value2 }: {
            value1: any;
            value2: any;
        }): number;
        betweenTwoNumbers({ figure, hexadecimal, compareArr }: {
            figure: number;
            hexadecimal: number;
            compareArr: number[];
        }): boolean;
    };
    date: {
        currentDateTime(): number;
        getDate(): number;
        getMonth(): number;
        getYear(): number;
        getTimezoneOffset(): string;
        getNowLocalTime(): number;
        getNowLocalUnixTime(): number;
        getTime(): number;
        stampToDate(timeStamp: any): Date;
        stampToTime(timeStamp: any): string;
        stampToDay({ timeStamp }: {
            timeStamp: any;
        }): {
            year: number;
            month: number;
            day: number;
        } | undefined;
        getTimeStampOfDate({ date }: {
            date: any;
        }): {
            start: number;
            end: number;
        };
        LoopToGenerate({ span }: {
            span: any;
        }): any[];
        calendarArray({ year, month, today }: {
            year: any;
            month: any;
            today: any;
        }): Record<string, any> | undefined;
        splitByTimeSlot({ object2, timeSlot, year, month, day }: {
            object2: any;
            timeSlot: any;
            year: any;
            month: any;
            day: any;
        }): any;
        splitTime({ object2, timeSlot, year, month, day, isSplitCurrent }: {
            object2: any;
            timeSlot: any;
            year: any;
            month: any;
            day: any;
            isSplitCurrent?: boolean | undefined;
        }): any;
        ShowTimeSpan(object: any): string | undefined;
        ShowTimeDate(object: any): string | undefined;
        ShowTimeDateUS(object: any): string | undefined;
        ShowTimeSpanFormat_us(object: any): string | undefined;
        minicalendarArray({ year, month, today, middleDay, span, color, backgroundColor, todayColor, todayBackgroundColor, }: {
            year: any;
            month: any;
            today: any;
            middleDay: any;
            span: any;
            color: any;
            backgroundColor: any;
            todayColor: any;
            todayBackgroundColor: any;
        }): Record<string, any>;
        loopMonth({ month, step }: {
            month: any;
            step: any;
        }): any;
        miniWeeklyCalendarArray({ year, month, today, markDay, color, backgroundColor, todayColor, todayBackgroundColor, currentDateTime, pastTimeColor, }: {
            year: any;
            month: any;
            today: any;
            markDay: any;
            color: any;
            backgroundColor: any;
            todayColor: any;
            todayBackgroundColor: any;
            currentDateTime: any;
            pastTimeColor?: null | undefined;
        }): Record<string, any> | undefined;
        NextWeek({ year, month, day }: {
            year: any;
            month: any;
            day: any;
        }): {
            year: number;
            month: number;
            day: number;
        };
        LastWeek({ year, month, day }: {
            year: any;
            month: any;
            day: any;
        }): {
            year: number;
            month: number;
            day: number;
        };
        AddHeightByTimeSpan({ object }: {
            object: any;
        }): any[] | undefined;
        ShowRightTime({ year, month, day, formatType }: {
            year: any;
            month: any;
            day: any;
            formatType?: string | undefined;
        }): string | number[] | undefined;
        ShowLeftTime({ year, month, day, formatType }: {
            year: any;
            month: any;
            day: any;
            formatType?: string | undefined;
        }): string | number[] | undefined;
        ShowDateByNumber({ year, month, day, formatType, abbreBool }: {
            year: any;
            month: any;
            day: any;
            formatType?: string | undefined;
            abbreBool?: boolean | undefined;
        }): string | undefined;
        TransformWeekDate({ object }: {
            object: any;
        }): {
            legend: {
                bottom: string;
                selectedMode: boolean;
                textStyle: {
                    color: string;
                };
            };
            grid: {
                left: string;
                right: string;
                top: string;
                bottom: string;
                containLabel: boolean;
            };
            xAxis: {
                type: string;
                interval: number;
                axisLabel: {
                    formatter: (value: any) => string | undefined;
                };
            };
            yAxis: {
                data: string[];
            };
            series: {
                type: string;
                renderItem: (params: any, api: any) => {
                    type: string;
                    shape: any;
                    style: any;
                };
                encode: {
                    x: number[];
                    y: number;
                };
                data: Record<string, any>;
            }[];
        } | undefined;
        transformMonth({ month, flag }: {
            month: any;
            flag?: number | undefined;
        }): any;
        transformYear({ year }: {
            year: any;
        }): number;
        getDurationByMinute({ stime, etime }: {
            stime: any;
            etime: any;
        }): number;
        startMeeting({ stime }: {
            stime: any;
        }): boolean;
        transformSelectWeek({ object }: {
            object: any;
        }): {
            selectWeek: Record<string, any>;
            addWeek: Record<string, any>;
        } | undefined;
        isType({ parameter, type }: {
            parameter: any;
            type: any;
        }): boolean;
        getQuarterStartMonth(now: number): number;
        getWeekEndDate(getTime: number): number;
        getMonthEndDate(getTime: number): number;
        getQuarterEndDate(getTime: number): number;
        compareTime({ startTime, endTime }: {
            startTime: any;
            endTime: any;
        }): boolean;
        DateCompare({ startTime, endTime }: {
            startTime: string;
            endTime: string;
        }): boolean | undefined;
        generateYear({ last, next }: {
            last?: number | undefined;
            next?: number | undefined;
        }): any;
        formatData(timeStamp: any): string;
        getMonthString(): string[];
        formatDataPro({ date, separator, retentionOptions }: {
            date: string | number;
            separator: string;
            retentionOptions?: boolean | undefined;
        }): string;
        checkUnder18({ date }: {
            date: any;
        }): boolean;
        timeRange({ queryType, stime, timeStart, timeEnd, }: {
            queryType: number;
            stime: number;
            timeStart: number;
            timeEnd: number;
        }): boolean | undefined;
        compareDate({ comTime, pareTime, timeStart, timeEnd, duration, indexTime, fomatTime }: {
            comTime: {
                [x: string]: any;
            };
            pareTime: {
                [x: string]: any;
            }[];
            timeStart?: string | undefined;
            timeEnd?: string | undefined;
            duration?: string | undefined;
            indexTime?: string | undefined;
            fomatTime?: string[] | undefined;
        }): boolean;
        JudgmentOrderTime(): boolean;
        getTimezone(): string;
    };
    search: {
        updateEsData({ id, type, bvid, }: {
            id: string;
            type: string;
            bvid: string | null;
        }): Promise<void>;
        transformGeo({ query }: {
            query: any;
        }): Promise<any[] | undefined>;
        queryCode({ query }: {
            query: any;
        }): Promise<any[][]>;
        queryInsurance({ id }: {
            id: any;
        }): Promise<any>;
        queryIns({ ins }: {
            ins: any;
        }): Promise<any>;
        queryAllCarriers({ object }: {
            object: any;
        }): Promise<any>;
        suggestAddress({ query }: {
            query: any;
        }): Promise<any>;
        suggest({ prefix }: {
            prefix: any;
        }): Promise<{
            uniqSym_suggestion: any[];
            speciality_suggestion: any[];
            symptom_suggestion: any[];
        }>;
        GetAllLonAndLat({ object }: {
            object: any;
        }): Record<string, any> | undefined;
        SortBySpeciality({ object }: {
            object: any;
        }): Record<string, any> | undefined;
        processingSearchData({ object }: {
            object: any;
        }): Record<string, any> | undefined;
        ComputeObjectFieldCount({ objArr, strOne, strTwo }: {
            objArr: any;
            strOne: any;
            strTwo: any;
        }): number[];
        ModifyObjectField({ objArr, str }: {
            objArr: any;
            str: any;
        }): any;
        CountObj({ objArr }: {
            objArr: any;
        }): {
            [key: string]: any;
        }[];
        pickByArr({ objArr }: {
            objArr: any;
        }): {}[];
        queryProviders({ cond }: {
            cond?: null | undefined;
        }): Promise<any>;
        GetAllLonAndLatNew({ object }: {
            object: any;
        }): Record<string, any> | undefined;
        GetFacilityLat({ object }: {
            object: any;
        }): Record<string, any> | undefined;
        ChooseCarrier({ object, cond }: {
            object: any;
            cond: any;
        }): any;
        jugeSame({ object, cond, name }: {
            object: any;
            cond: any;
            name: any;
        }): boolean;
        DeleteCarrier({ object, carreir, plans, len }: {
            object: any;
            carreir: any;
            plans: any;
            len: any;
        }): any;
        queryByAllDate({ cond, distance, pos, stime, etime, isSplitCurrent, }: {
            cond?: null | undefined;
            distance?: number | undefined;
            pos?: number | undefined;
            stime: any;
            etime: any;
            isSplitCurrent?: boolean | undefined;
        }): Promise<any>;
        queryAllUser({ cond, distance, pos, stime, etime, isSplitCurrent, }: {
            cond?: null | undefined;
            distance?: number | undefined;
            pos?: number | undefined;
            stime: any;
            etime: any;
            isSplitCurrent?: boolean | undefined;
        }): Promise<any>;
        queryUsers({ cond, distance, pos, lan, ins, stime, etime, isSplitCurrent, pages, total, isType, type }: {
            cond?: null | undefined;
            distance?: number | undefined;
            pos?: number | undefined;
            lan?: string | undefined;
            ins?: string | undefined;
            stime: any;
            etime: any;
            isSplitCurrent?: boolean | undefined;
            pages?: number | undefined;
            total?: never[] | undefined;
            isType?: boolean | undefined;
            type?: number | undefined;
        }): Promise<any>;
        querySpecialty({ cond, distance, pos, stime, etime, isSplitCurrent, isType, type, lan, ins }: {
            cond?: null | undefined;
            distance?: number | undefined;
            pos?: number | undefined;
            stime: any;
            etime: any;
            isSplitCurrent?: boolean | undefined;
            isType?: boolean | undefined;
            type?: number | undefined;
            lan?: string | undefined;
            ins?: string | undefined;
        }): Promise<never[]>;
        queryTotals({ cond, distance, pos, stime, etime, isSplitCurrent, isType, type, lan, ins }: {
            cond?: null | undefined;
            distance?: number | undefined;
            pos?: number | undefined;
            stime: any;
            etime: any;
            isSplitCurrent?: boolean | undefined;
            isType?: boolean | undefined;
            type?: number | undefined;
            lan?: string | undefined;
            ins?: string | undefined;
        }): Promise<any[]>;
        call({ telephone }: {
            telephone: any;
        }): Promise<void>;
        queryAllPat({ cond, distance, pos, stime, etime, isSplitCurrent, from, size, lastArray }: {
            cond?: null | undefined;
            distance?: number | undefined;
            pos?: number | undefined;
            stime: any;
            etime: any;
            isSplitCurrent?: boolean | undefined;
            from?: number | undefined;
            size?: number | undefined;
            lastArray?: never[] | undefined;
        }): Promise<any>;
        queryDataByType({ cond, distance, pos, stime, etime, type, isSplitCurrent, size, from, lastArray }: {
            cond: any;
            distance?: string | undefined;
            pos?: number | undefined;
            stime: any;
            etime: any;
            type: any;
            isSplitCurrent?: boolean | undefined;
            size?: number | undefined;
            from?: number | undefined;
            lastArray?: never[] | undefined;
        }): Promise<any>;
    };
    apiRequest: {
        drugBank({ query, id, type, }: {
            query: string | null;
            id: string | null;
            type: "Route" | "Strength" | "Drug";
        }): Promise<any>;
        dataBank({ query }: {
            query: string | null;
        }): Promise<any>;
        queryCPT({ query }: {
            query: any;
        }): Promise<any>;
    };
    typeCheck: {
        phoneNumber({ phoneNumber, countryCode }: {
            phoneNumber: any;
            countryCode: any;
        }): boolean;
        userName(userName: string): boolean;
    };
    ecos: {
        shareDoc({ sourceDoc, targetEdgeID, targetRoomName, targetFileID, reid }: {
            sourceDoc: any;
            targetEdgeID: any;
            targetRoomName: any;
            targetFileID: any;
            reid: any;
        }): Promise<import("@aitmed/ecos-lvl2-sdk").Level2Response | {
            jwt: any;
            error: any;
            doc: any;
            code: any;
        }>;
        shareDocByFid({ sourceDoc, targetEdgeID, targetRoomName }: {
            sourceDoc: any;
            targetEdgeID: any;
            targetRoomName: any;
        }): Promise<import("@aitmed/ecos-lvl2-sdk").Level2Response | {
            jwt: any;
            error: any;
            doc: any;
            code: any;
        }>;
        shareDocList({ sourceDocList, targetEdgeID, targetRoomName, targetFileID, reid, }: {
            sourceDocList: any;
            targetEdgeID: any;
            targetRoomName: any;
            targetFileID: any;
            reid: any;
        }): Promise<any[]>;
        updateDocList({ sourceDocList }: {
            sourceDocList: any;
        }): Promise<any[]>;
        updateDocListType({ sourceDocList, targetBit, targetValue }: {
            sourceDocList: any;
            targetBit: any;
            targetValue: any;
        }): Promise<any[]>;
        updateDocListReid({ sourceDocList, reid }: {
            sourceDocList: any;
            reid: any;
        }): Promise<any[]>;
        updateReidDocListType({ sourceDocList, targetBit, targetValue, sCondition, eid, }: {
            sourceDocList: any;
            targetBit: any;
            targetValue: any;
            sCondition: any;
            eid: any;
        }): Promise<void>;
        createFolderTag({ sourceDocList, folder, eid }: {
            sourceDocList: any;
            folder: any;
            eid: any;
        }): Promise<any[]>;
        deleteFolderTag({ sourceDocList, folder }: {
            sourceDocList: any;
            folder: any;
        }): Promise<any[]>;
        copyDocToAttachment({ sourceDocList, newType }: {
            sourceDocList: any;
            newType: any;
        }): Promise<any[]>;
        generatorSigForOldAccount({ id, name, sk, phoneNumber }: {
            id: any;
            name: any;
            sk: any;
            phoneNumber: any;
        }): Promise<{}>;
        transformVisitReason({ vertexId, rootNoteBookId }: {
            vertexId: any;
            rootNoteBookId: any;
        }): Promise<any>;
    };
    utils: {
        base64ToBlob({ data, type, }: {
            data: string;
            type: string;
        }): string | undefined;
        exists(args: Record<any, any>): boolean;
        log({ value }: {
            value: any;
        }): void;
        prepareDoc({ doc }: {
            doc: Record<string, any>;
        }): Promise<any>;
        prepareDocToPath(id: any): Promise<{
            type: any;
            url: any;
        } | undefined>;
        toaster({ toastMessage }: {
            toastMessage: any;
        }): void;
        getCountryCode({ uid }: {
            uid: string;
        }): string;
        getPhoneNumber({ uid }: {
            uid: string;
        }): string;
        getTempParams(): any;
        setTempParams({ Object }: {
            Object: any;
        }): void;
        setTimer({ timeUnix }: {
            timeUnix: number;
        }): void;
        removeTempParams(): void;
        removeKeyTempParams({ key }: {
            key: any;
        }): void;
        getFileSize({ object, units, }: {
            object: object;
            units: "kb" | "mb";
        }): string | 0;
        getFileName({ object }: {
            object: object;
        }): any;
        copyToClip({ object }: {
            object: object;
        }): number;
        setLocalStorage({ key, value }: {
            key: string;
            value: string;
        }): void;
        getLocalStorage({ key }: {
            key: string;
        }): string | null;
        cloneDeepData({ data }: {
            data: any;
        }): any;
        getUrl(): string;
        usernameCheck({ username }: {
            username: string;
        }): boolean;
        judgeAll({ value, index, }: {
            value: (string | number)[];
            index: string | number;
        }): boolean;
        areTheyIdentical({ data, comData }: {
            data: any;
            comData: any;
        }): boolean;
        isImageFile({ file }: {
            file: string;
        }): boolean;
        addArrayValue({ array }: {
            array: any;
        }): number;
        AWSOCR({ image }: {
            image: any;
        }): {
            DATE_OF_BIRTH: string;
            FIRST_NAME: string;
            LAST_NAME: string;
            MIDDLE_NAME: string;
            CITY_IN_ADDRESS: string;
            COUNTY: string;
            ADDRESS: string;
            ADDRESS_SECOND_LINE: string;
            STATE_IN_ADDRESS: string;
            ZIP_CODE_IN_ADDRESS: string;
            DOCUMENT_NUMBER: string;
            ID_TYPE: string;
        };
        gethashCode({ hashFields, hashtime, }: {
            hashFields: string[];
            hashtime?: number | undefined;
        }): string;
        setEmpty({ variable, identifier }: {
            variable: any[];
            identifier: string;
        }): any[] | undefined;
    };
    math: {
        random: () => number;
        add: ({ num1, num2 }: {
            num1: number;
            num2: number;
        }) => number;
        greater: ({ num1, num2 }: {
            num1: number;
            num2: number;
        }) => boolean;
        lessthanSize: ({ object, key }: {
            object: {};
            key: number;
        }) => boolean;
        cumulative: ({ numArr }: {
            numArr: [];
        }) => number;
        toFixedNum({ num }: {
            num: string | number;
        }): string;
        FixedLimit({ num }: {
            num: string | number;
        }): boolean;
        calculateAge({ dateTime, splite }: {
            dateTime: string;
            splite?: string | undefined;
        }): number;
    };
    FCM: {
        getFCMToken({ token }: {
            token: any;
        }): any;
        getAPPID({ appName }: {
            appName: any;
        }): string;
        getFCMTokenSHA256Half({ token }: {
            token: any;
        }): string;
    };
    payment: {
        createSqPaymentForm(): void;
        getPaymentNonce(): string | undefined;
    };
    getRootNotebook(args: any): Promise<any>;
    createNewAccount(args: any): Promise<any>;
    signIn({ phoneNumber, password, verificationCode }: {
        phoneNumber: any;
        password: any;
        verificationCode: any;
    }): Promise<any>;
    loginByPassword(password: any): Promise<void>;
    storeCredentials({ pk, sk, esk, userId, facilityId }: {
        pk: any;
        sk: any;
        esk: any;
        userId: any;
        facilityId: any;
    }): Promise<void>;
    storeCredential({ key, value }: {
        key: any;
        value: any;
    }): Promise<void>;
    currentDateTime: number;
    SignInOk(): Promise<boolean>;
    uploadDocument({ title, tags, content, type, dataType, }: {
        title: any;
        tags?: never[] | undefined;
        content: any;
        type: any;
        dataType?: number | undefined;
    }): Promise<Record<string, any>>;
    isIOS(): boolean;
    isAndroid(): boolean;
    isIOSBrowser(): boolean;
    isAndroidBroswer(): boolean;
    isAndroidBrowser(): boolean;
    stringCompare(string1: string, string2: string): boolean;
    toCSV(value: Record<string, any> | any[]): string | string[];
    downloadFromS3(url: any): Promise<any>;
    cleanLocalStorage(): Promise<void>;
    searchCache({ key }: {
        key: string;
    }): Promise<any>;
    isBrowser(): boolean;
};
