declare const _default: {
    /**
     * @function
     * @description Returns the number of milliseconds between January 1, 1970
     * @returns {Number}
     */
    currentDateTime(): number;
    /**
     * @function
     * @description Get the current day date
     * @returns {Number}
     */
    getDate(): number;
    /**
     * @function
     * @description Get the current month
     * @returns {Number}
     */
    getMonth(): number;
    /**
     * @function
     * @description Get the current year
     * @returns {Number}
     */
    getYear(): number;
    /**
     * @function
     * @description Returns the time difference between UTC and local time
     * @returns {String}
     */
    getTimezoneOffset(): string;
    /**
     * @function
     * @description Returns the number of milliseconds between January 1, 1970
     * @returns {Number}
     */
    getNowLocalTime(): number;
    /**
     * @function
     * @description Returns the number of seconds since January 1, 1970 00:00:00 (UTC) to the current time
     * @returns {Number}
     */
    getNowLocalUnixTime(): number;
    /**
     * @function
     * @description Returns the number of seconds since January 1, 1970 00:00:00 (UTC) to the current time
     * @returns {Number}
     */
    getTime(): number;
    /**
     * @function
     * @description timestamp converted to date
     * @param {Number} timeStamp
     * @returns {Number}
     */
    stampToDate(timeStamp: any): Date;
    /**
     * @function
     * @description Timestamp is converted to hours, similar to 2:00AM
     * @param {Number} timeStamp
     * @returns {String}
     */
    stampToTime(timeStamp: any): string;
    /**
     * @function
     * @description timestamp--> year,month,day
     * @param timeStamp
     * @returns {Object}
     */
    stampToDay({ timeStamp }: {
        timeStamp: any;
    }): {
        year: number;
        month: number;
        day: number;
    } | undefined;
    /**
     * @function
     * @description Returns the time stamp interval of a day  (s)
     * @param {string} date
     * @return {Number}
     */
    getTimeStampOfDate({ date }: {
        date: any;
    }): {
        start: number;
        end: number;
    };
    /**
     * @function
     * @description Divide 24h into intervals
     * @param {Number} span
     * @returns {Array}
     */
    LoopToGenerate({ span }: {
        span: any;
    }): any[];
    /**
     * @function
     * @description Get all dates of the current month based on year, month, and day
     * @param {Number} year
     * @param {Number} month
     * @param {Number} today
     * @returns {Array}
     */
    calendarArray({ year, month, today }: {
        year: any;
        month: any;
        today: any;
    }): Record<string, any> | undefined;
    /**
     * @function
     * @description Divide the time period according to the edge's stime, etime and timeSlot
     * @param {Array} object2
     * @param {Number} timeSlot
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @returns {Array}
     */
    splitByTimeSlot({ object2, timeSlot, year, month, day }: {
        object2: any;
        timeSlot: any;
        year: any;
        month: any;
        day: any;
    }): any;
    /**
     * @function
     * @description Divide the time period according to the edge's stime, etime and timeSlot.
     * And according to whether the isSplitCurrent removes the time period between the current time
     * @param {Array} object2
     * @param {Number} timeSlot
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @param {Boolean} isSplitCurrent
     * @returns {Array}
     */
    splitTime({ object2, timeSlot, year, month, day, isSplitCurrent }: {
        object2: any;
        timeSlot: any;
        year: any;
        month: any;
        day: any;
        isSplitCurrent?: boolean | undefined;
    }): any;
    /**
     * @function
     * @description According to stime, etime displays date start and end similar to 9:17 AM-7:04 PM
     * @param {Object} object
     * @returns {String}
     */
    ShowTimeSpan(object: any): string | undefined;
    /**
     * @function
     * @description According to stime, etime displays the date similar to 2021-08-20
     * @param {Object} object
     * @returns {String}
     */
    ShowTimeDate(object: any): string | undefined;
    /**
     * @function
     * @description According to stime, etime displays the date similar to 2021-08-20
     * @param {Object} object
     * @returns {String}
     */
    ShowTimeDateUS(object: any): string | undefined;
    /**
     * @function
     * @description According to stime, etime displays the date similar to 08-20-2021 9:17 AM-7:04 PM
     * @param {Object} object
     * @returns {Array}
     */
    ShowTimeSpanFormat_us(object: any): string | undefined;
    /**
     * @function
     * @description Get all dates of the current month based on year, month, and day
     * @param {Number} year
     * @param {Number} month
     * @param {Number} today
     * @param {Number} middleDay
     * @param {Number} span
     * @param {String} color
     * @param {String} backgroundColor
     * @param {String} todayColor
     * @param {String} todayBackgroundColor
     * @returns {Array}
     */
    minicalendarArray({ year, month, today, middleDay, span, color, backgroundColor, todayColor, todayBackgroundColor, }: {
        year: any;
        month: any;
        today: any;
        middleDay: any;
        span: any;
        color: any;
        backgroundColor: any;
        todayColor: any;
        todayBackgroundColor: any;
    }): Record<string, any>;
    /**
     * @function
     * @description Add and subtract months
     * @param {Number} month
     * @param {Number} step
     * @returns {Number}
     */
    loopMonth({ month, step }: {
        month: any;
        step: any;
    }): any;
    /**
     * @function
     * @description Get all dates of the current Week based on year, month, and day
     * @param {Number} year input year
     * @param {Number} month input month
     * @param {Number} today input today,this can generate today font color and backgroundcolor
     * @param {Number} markDay Generate week time according this param
     * @param {String} color   font color of common date
     * @param {String} backgroundColor  background color of common date
     * @param {String} todayColor  font color of today
     * @param {String} todayBackgroundColor background color of today
     * @returns {Array}
     * return data formate:
     * [{year: 2021,month: 3,day: 28,weekDay: 'Su',color: '#000000', backgroundColor: '#ffffff'}]
     */
    miniWeeklyCalendarArray({ year, month, today, markDay, color, backgroundColor, todayColor, todayBackgroundColor, currentDateTime, pastTimeColor, }: {
        year: any;
        month: any;
        today: any;
        markDay: any;
        color: any;
        backgroundColor: any;
        todayColor: any;
        todayBackgroundColor: any;
        currentDateTime: any;
        pastTimeColor?: null | undefined;
    }): Record<string, any> | undefined;
    /**
     * @function
     * @description Get the next week's date based on the current date
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @returns {Object}
     */
    NextWeek({ year, month, day }: {
        year: any;
        month: any;
        day: any;
    }): {
        year: number;
        month: number;
        day: number;
    };
    /**
     * @function
     * @description Get the last week's date based on the current date
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @returns {Object}
     */
    LastWeek({ year, month, day }: {
        year: any;
        month: any;
        day: any;
    }): {
        year: number;
        month: number;
        day: number;
    };
    /**
     * @function
     * @description Add a height attribute to each item below the array
     * @param {Array} object
     * @returns {Array}
     */
    AddHeightByTimeSpan({ object }: {
        object: any;
    }): any[] | undefined;
    /**
     * @function
     * @description The default date format is week month day, year (such as Saturday April 10, 2021)
     * customized to YMD (year, month, day), and place the corresponding year, month,
     * and day according to the position of YMD (such as "YMD" corresponds to "2021 -04-10")
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @param {String} formatType
     * @returns {String}
     */
    ShowRightTime({ year, month, day, formatType }: {
        year: any;
        month: any;
        day: any;
        formatType?: string | undefined;
    }): string | number[] | undefined;
    /**
     * @function
     * @description The default date format is week month day, year (such as Saturday April 10, 2021)
     * customized to YMD (year, month, day), and place the corresponding year, month,
     * and day according to the position of YMD (such as "YMD" corresponds to "2021 -04-10")
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @param {String} formatType
     * @returns {String}
     */
    ShowLeftTime({ year, month, day, formatType }: {
        year: any;
        month: any;
        day: any;
        formatType?: string | undefined;
    }): string | number[] | undefined;
    /**
     * @function
     * @description The default date format is week month day, year (such as Saturday April 10, 2021)
     * customized to YMD (year, month, day), and place the corresponding year, month,
     * and day according to the position of YMD (such as "YMD" corresponds to "2021 -04-10")
     * @param {Number} year
     * @param {Number} month
     * @param {Number} day
     * @param {String} formatType
     * @returns {String}
     */
    ShowDateByNumber({ year, month, day, formatType, abbreBool }: {
        year: any;
        month: any;
        day: any;
        formatType?: string | undefined;
        abbreBool?: boolean | undefined;
    }): string | undefined;
    /**
     * @function
     * @description Options for generating echart week time chart
     * @param {Array} object
     * @returns {Object}
     */
    TransformWeekDate({ object }: {
        object: any;
    }): {
        legend: {
            bottom: string;
            selectedMode: boolean;
            textStyle: {
                color: string;
            };
        };
        grid: {
            left: string;
            right: string;
            top: string;
            bottom: string;
            containLabel: boolean;
        };
        xAxis: {
            type: string;
            interval: number;
            axisLabel: {
                formatter: (value: any) => string | undefined;
            };
        };
        yAxis: {
            data: string[];
        };
        series: {
            type: string;
            renderItem: (params: any, api: any) => {
                type: string;
                shape: any;
                style: any;
            };
            encode: {
                x: number[];
                y: number;
            };
            data: Record<string, any>;
        }[];
    } | undefined;
    /**
     * @function
     * @description Convert numeric month to text month
     * @param {Number} month
     * @param {Number} flag
     * @returns {String}
     */
    transformMonth({ month, flag }: {
        month: any;
        flag?: number | undefined;
    }): any;
    /**
     * @function
     * @description transform year to int type
     * @param {String} year
     * @returns {Number}
     */
    transformYear({ year }: {
        year: any;
    }): number;
    /**
     * @function
     * @description Get the distance between stime and etime in minutes
     * @param {Number} stime
     * @param {Number} etime
     * @returns {Number}
     */
    getDurationByMinute({ stime, etime }: {
        stime: any;
        etime: any;
    }): number;
    /**
     * @function
     * @description Determine whether the current time is within 15 minutes before stime
     * @param {Number} stime
     * @returns {Boolean}
     */
    startMeeting({ stime }: {
        stime: any;
    }): boolean;
    /**
     * @function
     * @description According to the current array, generate the selected time within a week
     * @param {Array} object
     * @returns {Object}
     */
    transformSelectWeek({ object }: {
        object: any;
    }): {
        selectWeek: Record<string, any>;
        addWeek: Record<string, any>;
    } | undefined;
    /**
     * @function
     * @description Determine whether the current parameter is of the specified type
     * @param {any} parameter
     * @param {String} type
     * @returns {Boolean}
     */
    isType({ parameter, type }: {
        parameter: any;
        type: any;
    }): boolean;
    /**
     * @function
     * @description Get thr month that the current Quarter starts
     * @param {Number} now
     * @returns {Number}
     */
    getQuarterStartMonth(now: number): number;
    /**
     * @function
     * @description Get the date of the last day of the current week in getTime
     * @param {Number} getTime
     * @returns {Number}
     */
    getWeekEndDate(getTime: number): number;
    /**
     * @function
     * @description Get the date of the last day of the current month in getTime
     * @param {Number} getTime
     * @returns {Number}
     */
    getMonthEndDate(getTime: number): number;
    /**
     * @function
     * @description Get thr month that the current Quarter ends
     * @param {Number} getTime
     * @returns {Number}
     */
    getQuarterEndDate(getTime: number): number;
    /**
     * @function
     * @description Determine startTime is less than endTime
     * @param {Number} startTime
     * @param {Number} endTime
     * @returns {Boolean}
     */
    compareTime({ startTime, endTime }: {
        startTime: any;
        endTime: any;
    }): boolean;
    /**
     * @function
     * @description Determine startTime is less than endTime
     * @param {Number} startTime
     * @param {Number} endTime
     * @returns {Boolean}
     */
    DateCompare({ startTime, endTime }: {
        startTime: string;
        endTime: string;
    }): boolean | undefined;
    /**
     * @function
     * @description Generate an array of years
     * @param {Number} last
     * @param {Number} next
     * @returns {Array}
     */
    generateYear({ last, next }: {
        last?: number | undefined;
        next?: number | undefined;
    }): any;
    /**
     * @function
     * @description TimeStamp is converted to time similar to 2:00AM
     * @param {Number} timeStamp
     * @returns {String}
     */
    formatData(timeStamp: any): string;
    /**
     * @function
     * @description Get the month after the current date
     * @returns {Array}
     */
    getMonthString(): string[];
    /**
     * @function
     * @description According to the date generation date is similar to month,day,year,hour,minute,AM｜PM
     * @param {Number | String} date
     * @param {String} separator Date dividing line
     * @returns {String}
     */
    formatDataPro({ date, separator, retentionOptions }: {
        date: number | string;
        separator: string;
        retentionOptions?: boolean | undefined;
    }): string;
    /**
     * @function
     * @description According to date (such as 1998-09-02) to determine whether the current is greater than 18 years old
     * @param {String} date type such as 1998-09-02
     * @returns {Boolean}
     */
    checkUnder18({ date }: {
        date: any;
    }): boolean;
    /**
     * @function
     * @description queryType——judgment type, number type
     * When it is 1, it means to judge whether the current time is within the range of stime greater than timeStart
     * When it is 2, it means to judge whether the current time is less than the range of timeEnd from stime
     * When it is 3, it means to judge whether the current time is in the range greater than timeStart and less than timeEnd from stime
     * stime-appointment time, timestamp type, in seconds
     * timeStart, timeEnd-the unit is minutes, if not required, the default is -1
     * @param {Number} queryType 1|2|3
     * @param {Number} stime
     * @param {Number} timeStart start time
     * @param {Number} timeEnd end time
     * @returns {Boolean}
     */
    timeRange({ queryType, stime, timeStart, timeEnd, }: {
        queryType: number;
        stime: number;
        timeStart: number;
        timeEnd: number;
    }): boolean | undefined;
    /**
     * @function
     * @description Judge whether the incoming time overlaps or overlaps with other times
     * @param {object} comTime
     * @param {object[]} pareTime
     * @param {string} timeStart
     * @param {string} timeEnd
     * @param {string} duration
     * @param {string} indexTime
     * @param {string[]} fomatTime
     * @returns {Boolean}
     */
    compareDate({ comTime, pareTime, timeStart, timeEnd, duration, indexTime, fomatTime }: {
        comTime: {
            [x: string]: any;
        };
        pareTime: {
            [x: string]: any;
        }[];
        timeStart?: string | undefined;
        timeEnd?: string | undefined;
        duration?: string | undefined;
        indexTime?: string | undefined;
        fomatTime?: string[] | undefined;
    }): boolean;
    /**
     * @function
     * @description Judge whether the incoming time overlaps or overlaps with other times
     * @param {void}
     * @returns {boolean}
     */
    JudgmentOrderTime(): boolean;
    /**
     * @function
     * @description get timezone
     * @param {void}
     * @returns {string}
     */
    getTimezone(): string;
};
export default _default;
