declare type keyValue = {
    key: string;
    value: string;
};
declare const _default: {
    /**
     * @function
     * @description Remove key value pairs from objects through properties
     * @param {object} object
     * @param {string} key
     * @returns {void}
     */
    remove({ object, key }: {
        object: {};
        key: string;
    }): void;
    /**
     * @function
     * @description Assign the value of an attribute of an object to null
     * @param {object} object
     * @param {string} key
     * @returns {void}
     */
    clear({ object, key }: {
        object: {};
        key: string;
    }): void;
    /**
     * @function
     * @description Set key value pairs for objects
     * @param {object} object
     * @param {string} key
     * @param {string} value
     * @returns {void}
     */
    set({ object, key, value }: {
        object: {};
        key: string;
        value: any;
    }): void;
    /**
     * @function
     * @description Set key value pairs for each item in the object array
     * @param {array} objectArr
     * @param {string} key
     * @param {string} value
     * @returns {void}
     */
    setObjectKey({ objectArr, key, value, }: {
        objectArr: {}[];
        key: string;
        value: any;
    }): {}[];
    /**
     * @function
     * @description Gets a value of an object
     * @param {array} objectArr
     * @param {string} key
     * @returns {any}
     */
    get({ object, key }: {
        object: {};
        key: string;
    }): any;
    /**
     * @function
     * @description Determine whether there is an attribute in the object
     * @param {object} object
     * @param {string} key
     * @returns {boolean}
     */
    has({ object, key }: {
        object: {};
        key: string;
    }): boolean | undefined;
    /**
     * @function
     * @description Loop to determine whether the value of an object under a path is equal to false.
     * If yes, it returns true, and if no, it returns false
     * @param {array} objArr
     * @param {string} valPath
     * @returns {boolean}
     */
    objectHasValue({ objArr, valPath, }: {
        objArr: {
            [key: string]: {};
        }[];
        valPath: string;
    }): boolean;
    /**
     * @function
     * @description clears one key of all items of object, and set one item，for list radio
     * @param {array} object
     * @param {array} item
     * @param {string} key
     * @param {string} value
     * @returns {void}
     */
    clearAndSetKey({ object, item, key, value, }: {
        object: {
            [x: string]: any;
        }[];
        item: {};
        key: string;
        value: any;
    }): void;
    /**
     * @function
     * @description Extract an item from multiple arrays
     * @param {array} array
     * @param {string} field
     * @returns {array}
     */
    extract({ array, field }: {
        array: any[];
        field: string;
    }): any[];
    /**
     * @function
     * @description Convert the two passed in arrays into object arrays according to the corresponding properties
     * @param {array} obj
     * @param {array} arr
     * @returns {array}
     */
    extractArray({ obj, arr }: {
        obj: any[];
        arr: any[];
    }): any[] | "";
    /**
     * @function
     * @description Sets the value of the subtype of another object property
     * according to one object property and returns the numeric array type
     * @param {array} auth
     * @param {array} authList
     * @returns {array}
     */
    authToSubType({ auth, authList, }: {
        auth: {
            [x: string]: any;
        };
        authList: {
            [x: string]: any;
        };
    }): number[];
    /**
     * @function
     * @description Set the true value of the object's property according to the true value of the
     * object's specific property, and return the object
     * @param {object} object
     * @returns {object}
     *
     */
    findTrue({ object }: {
        object: {
            [x: string]: any;
        };
    }): {
        Settings: boolean;
        UserManagement: boolean;
        Schedule: boolean;
    };
    /**
     * @function
     * @description Set the values of all properties of the object to true (only two levels of depth),
     *  and return the object
     * @param {object} object
     * @returns {object}
     *
     */
    setAuthAllTrue({ object }: {
        object: {
            [x: string]: any;
        };
    }): {
        [x: string]: any;
    };
    /**
     * @function
     * @description Judge whether the object is empty
     * @param {object} object
     * @returns {boolean}
     *
     */
    isEmpty({ object }: {
        object: any;
    }): boolean;
    /**
     * @function
     * @description Set the value of the object whose attribute is key to value
     * @param {object} object
     * @param {string} key
     * @param {any} value
     * @returns {void}
     *
     */
    setByKey({ object, key, value, }: {
        object: {
            [x: string]: any;
        };
        key: any;
        value: any;
    }): void;
    /**
     * @function
     * @description The key and value of an object are obtained according to the attribute value of an object,
     * and encapsulated into an object return
     * @param {object} objects
     * @param {array} objStr
     * @returns {object}
     *
     */
    getObjValueAndKey({ objects, objStr, }: {
        objects: {
            [x: string]: any;
        };
        objStr: any;
    }): Object;
    /**
     * @function
     * @description Get the key of the object and return
     * @param {object} objects
     * @returns {array}
     *
     */
    getObjKey({ objects, }: {
        objects: {
            [x: string]: any;
        };
    }): string[] | null;
    /**
     * @function
     * @description Get the key of the object, return the key and value
     * of the split object, encapsulate each item of the object into a separate object, put it into the array and return
     * @param {object} object
     * @returns {array}
     *
     */
    getObjWithKV({ object }: {
        object: any[];
    }): keyValue[];
    /**
     * @function
     * @description Compare the passed in property values,
     * set the property values of related objects, and return the object
     * @param {object} obj
     * @param {string} label
     * @param {string} text
     * @param {string[]} arr
     * @param {string[]} valueArr
     * @param {string[]} valueArr
     * @returns {object}
     *
     */
    setProperty({ obj, label, text, arr, valueArr, errorArr, }: {
        obj: {
            [key: string]: any;
        }[];
        label: string;
        text: string;
        arr: string[];
        valueArr: string[];
        errorArr: string[];
    }): {
        [key: string]: any;
    }[];
    /**
     * @function
     * @description Judge whether the object is visitreason or telemedicine, and color it
     * @param {array} obj
     * @returns {array}
     */
    setTimeProperty({ obj }: {
        obj: {
            [key: string]: any;
        }[];
    }): any;
    /**
     * @function
     * @description Empty the incoming object
     * @param {object} objects
     * @returns {void}
     *
     */
    clearAll({ object }: {
        object: {
            [x: string]: any;
        };
    }): void;
    /**
     * @function
     * @description Format the object array according to the passed path
     * and Boolean value. If bool is true, the attributes of the array
     * object will be capitalized. If bool is false, the operation will
     * not be carried out (as the filtering function of the address book)
     * @param {array} objArrs
     * @param {string[]} pathObj
     * @param {boolean} bool
     * @returns {array}
     *
     */
    extractingFeatureStrings({ objArrs, pathObj, bool, }: {
        objArrs: {}[];
        pathObj: string[];
        bool?: boolean | undefined;
    }): string | {
        [key: string]: string[];
    }[];
    /**
     * @function
     * @description Add key and value values to each object
     * @param {object} object
     * @param {string} key
     * @param {any} value
     * @returns {void}
     *
     */
    addKey({ object, key, value }: {
        object: {}[];
        key: string;
        value: any;
    }): {}[];
    /**
     * @function
     * @description Delete key value pair
     * @param {object} object
     * @param {string[]} path
     * @returns {object}
     *
     */
    deleteKey({ object, path }: {
        object: {};
        path: string[];
    }): {};
    /**
     * @function
     * @description Determine whether there are native attributes
     * @param {object} object
     * @param {string[]} keyArr
     * @returns {boolean}
     */
    hasMultipleKeys({ object, keyArr }: {
        object: {};
        keyArr: string[];
    }): boolean;
    /**
     * @function
     * @description Judge the status according to the type value
     * @param {object} object
     * @param {string} type
     * @param {string} state
     * @returns {string}
     */
    transformStatus(object: {
        [x: string]: any;
    }, type?: string, state?: string): string;
    /**
     * @function
     * @description Judge whether the attribute value of the incoming object contains false
     * @param {object} object
     * @param {string} type
     * @param {string} state
     * @returns {string}
     */
    judgeAllTrue({ object }: {
        object: {
            [x: string]: any;
        };
    }): boolean;
    /**
     * @function
     * @description Set multiple attribute values on the array
     * @param {object[]} obj
     * @param {string} label
     * @param {any} checkValue
     * @param {string[]} arr
     * @param {string[]} valueArr
     * @param {string[]} errorArr
     * @returns {object}
     */
    setMultipleProperty({ obj, label, checkValue, arr, valueArr, errorArr, }: {
        obj: {
            [key: string]: any;
        }[];
        label: string;
        checkValue: any;
        arr: string[];
        valueArr: string[];
        errorArr: string[];
    }): any;
    /**
     * @function
     * @description Encapsulate the passed in object array with specific attribute values
     * @param {object[]} originalObjArr
     * @param {string[]} pathArr
     * @returns {object[]}
     */
    eEncapsulatedObj({ originalObjArr, pathArr }: {
        originalObjArr: {
            [x: string]: any;
        }[];
        pathArr: string[];
    }): {
        [x: string]: any;
    }[];
    /**
     * @function
     * @description Encapsulate the incoming object as CSV
     * @param {object} arrObj
     * @returns {object|string}
     */
    toCsvFormat({ arrObj }: {
        arrObj: {
            [x: string]: any;
        };
    }): string | {
        [x: string]: any;
    };
    /**
     * @function
     * @description Match the fields you want to search
     * @param {object[]} objArr
     * @param {string[]} paths
     * @param {string | number} value
     * @returns {object[]}
     */
    matchSearchValue({ objArr, paths, value }: {
        objArr: {
            [x: string]: any;
        }[];
        paths: string[];
        value: string | number;
    }): {
        [x: string]: any;
    }[];
    /**
     * @function
     * @description Delete object field
     * @param {object} obj
     * @returns {undefined}
     */
    clearObject({ obj }: {
        obj: object;
    }): void;
    /**
     * @function
     * @description Find the changed object field and encapsulate it
     * @param {object} object
     * @param {object} baseObject
     * @returns {Array}
     */
    difference({ object, baseObject }: {
        object: {
            [x: string]: any;
        };
        baseObject: {
            [x: string]: any;
        };
    }): {
        [x: string]: any;
    };
    /**
     * @function
     * @description modify Object Properties
     * @param {obj} object
     * @param {string[]} keyArr
     * @param {boolean} bool
     * @returns {Array}
     */
    modifyObjectProperties({ obj, keyArr, bool }: {
        obj: object;
        keyArr: string[];
        bool: boolean;
    }): any;
    /**
     * @function
     * @description set Object Display And Color
     * @param {obj} object
     * @returns {object}
     */
    setObjDisplayAndColor({ obj }: {
        obj: object;
    }): object;
};
export default _default;
