import { AnyArray } from 'immer/dist/internal';
declare const _default: {
    /**
     * @function
     * @description Format the time to output the format of hour, minute and second (example: 08:02:14)
     * @param {number} time
     * @returns {string}
     *
     */
    formatTimer(time: number, type?: string): string;
    /**
     * @function
     * @description Format and output the difference from Greenwich mean time
     * (for example: 51 years, 7 months, 2 weeks, 3 days, 5 hours, 8 minutes, 33.604 seconds)
     * @param {number} unixTime
     * @returns {string}
     *
     */
    formatUnixtimeSecond(unixTime: number): string;
    /**
     * @function
     * @description Format time (for example: Nov 23, 2021 10:01 AM)
     * @param {number} unixTime (millisecond)
     * @returns {string}
     *
     */
    formatNowTime(): string;
    /**
     * @function
     * @description Format time (for example: Nov 23, 2021 10:01 AM)
     * @param {number} unixTime (second)
     * @returns {string}
     *
     */
    formatUnixtime_en(unixTime: number | string): any;
    /**
     * @function
     * @description Format time (for example: 7/12/2021)
     * @param {number} unixTime (second)
     * @returns {string}
     *
     */
    formatUnixtimeL_en(unixTime: number): string;
    /**
     * @function
     * @description Format time (for example: 5:20 PM)
     * @param {number} unixTime (second)
     * @returns {string}
     *
     */
    formatUnixtimeLT_en(unixTime: number): string;
    /**
     * @function
     * @description Format time (for example: 51 years, 10 months, 3 weeks, 23 hours, 12 minutes, 3.212 seconds)
     * @param {number} unixTime (second)
     * @returns {string}
     *
     */
    formatDurationInSecond(unixTime: number): any;
    /**
     * @function
     * @description Format time (for example: Nov 23, 2021 10:13 AM)
     * @param {number} unixTime (millisecond)
     * @returns {string}
     *
     */
    formatDurationInMicroSecond(unixTime: number): string;
    /**
     * @function
     * @description Concatenation character array
     * @param {array} stringArr
     * @returns {string}
     *
     */
    concat(stringArr: string[]): string;
    /**
     * @function
     * @description Concatenate character arrays, excluding spaces
     * @param {array} stringArr
     * @returns {string}
     *
     */
    concatTrim(strValue: string[]): string;
    /**
     * @function
     * @description Splice two arrays, divide the values in the string with length of 16 equally
     *  and output them (for example: ['ABSN', 'DMLD', 'KIPO', 'lsdf'])
     * @param {string} key
     * @returns {string[]}
     *
     */
    split16DkeytoArray(key: string): string[];
    /**
     * @function
     * @description Cut the value in the string with length of 16 and output it
     * (example: please let your friend enter this code on their side: ABSN DMLD KIPO lsdf)
     * @param {string} Dkey
     * @returns {string}
     *
     */
    split16Dkey(Dkey: string): string;
    /**
     * @function
     * @description Judge whether two strings are equal (example: 2 == "2","a" == "a")
     * @param {string} string1
     * @param {string} string2
     * @returns {boolean}
     *
     */
    equal({ string1, string2 }: {
        string1: string;
        string2: string;
    }): boolean;
    /**
     * @function
     * @description Gets the first letter of the string and converts it to uppercase
     * @param {string} value
     * @returns {string|void}
     *
     */
    getFirstChar({ value }: {
        value: string;
    }): string | void;
    /**
     * @function
     * @description Get string length
     * @param {string} str
     * @returns {number}
     *
     */
    getLength(str: any): number;
    /**
     * @function
     * @description Convert characters to numbers
     * @param {string} value
     * @returns {number}
     *
     */
    retainNumber({ value }: {
        value: string;
    }): number;
    /**
     * @function
     * @description Verify whether the number is correct and return the Boolean value
     * @param {string} countryCode country code of phone number
     * @param {string} phoneNumber phone number
     * @returns {boolean}
     */
    phoneVerification({ countryCode, phoneNumber }: {
        countryCode: string;
        phoneNumber: number | string;
    }): boolean;
    /**
     * @function
     * @description Cut the string according to the sign parameter
     * @param {number} phonenumber
     * @param {string} sign
     * @returns {array}
     */
    phoneNumberSplit({ phoneNumber, sign }: {
        phoneNumber: number;
        sign: string;
    }): AnyArray;
    /**
     * @function
     * @description judge whether all string equal
     * @param {string[]} stringArr
     * @returns {boolean}
     */
    judgeMultipleEqual(stringArr: string[]): boolean;
    /**
     * @function
     * @description Cut the string according to the sign parameter, judge whether the
     * value in the character array has a value starting with the $symbol, and return a Boolean value
     * @param {string[]} stringArr
     * @returns {boolean}
     */
    judgeSelectTime(stringArr: string[]): boolean;
    /**
     * @function
     * @description judge whether all the request textfield is filled in
     * @param {string[]} stringArr
     * @returns {boolean}
     */
    judgeFillinAll(stringArr: string[]): boolean;
    /**
     * @function
     * @description Judge whether the array is all empty. If it is all empty, return true; otherwise, return false
     * @param {string[]} stringArr
     * @returns {boolean}
     */
    judgeIsAllEmpty(stringArr: string[]): boolean;
    /**
     * @function
     * @description Splice string
     * @param {string} str1
     * @param {string} str2
     * @param {string} str
     * @returns {string}
     */
    judgeAllTrue({ str1, str2, str3 }: {
        str1: string;
        str2: string;
        str3: string;
    }): string;
    /**
     * @function
     * @description Determines whether the object property is empty (only two levels of depth) and returns a Boolean value
     * @param {object} object
     * @returns {string}
     */
    judgesFillinAll(object: any): boolean;
    /**
     * @function
     * @description Manipulate the value of the object, add spaces and commas, and return the spliced string
     * @param {any} obj
     * @returns {string}
     */
    strLenx({ obj }: {
        obj: {};
    }): string;
    /**
     * @function
     * @description Calculate the distance based on the longitude and latitude obtained by this software
     * and the incoming longitude and latitude
     * @param {array} point => longitude and latitude parameters
     * @returns {string|void}
     */
    distanceByPosition(point: any): string | undefined;
    /**
     * @function
     * @description Parse the address data obtained by mapbox
     * @param {object} object => mapbox daddress data
     * @returns {object}
     */
    getAddress({ object }: {
        object: {
            [x: string]: any;
        };
    }): {
        address: string;
        city: string;
        state: string;
        zipCode: string;
        location: string;
        geoCode: never[];
        country: string;
        county: string;
        firsLine: string;
        SecondLine: string;
        distance: string;
    };
    /**
     * @function
     * @description  Cut and splice the string ID
     * @param {string} facilityID =>facilityID
     * @param {string} locationID =>local loaction's ID
     * @param {string} roomID =>local room's ID
     * @returns {string}
     */
    generateID({ facilityID, locationID, roomID }: {
        facilityID: string;
        locationID: string;
        roomID: string | number;
    }): string;
    /**
     * @function
     * @description  Returns the size of the document and formats the result
     * @param {string} bitNum
     * @returns {string}
     */
    bitFormatting(bitNum: number): string;
    /**
     * @function
     * @description  Judge whether two given strings have substrings of the same length
     * @param {string} stringOne
     * @param {string} stringTwo
     * @param {number} len
     * @returns {boolean}
     */
    equalsLenString({ stringOne, stringTwo, len }: {
        stringOne: string;
        stringTwo: string;
        len: number;
    }): boolean;
    /**
     * @function
     * @description  Splice and match according to the entered $ format
     * @param {number|string} fund
     * @returns {string}
     */
    dollarFormat(fund: any): any;
    /**
     * @function
     * @description parse Splice String
     * @param {number | string} value
     * @param {object[]} objArr
     * @param {string} path
     * @param {string} pathItem
     * @returns {string}
     */
    parseSpliceString({ value, objArr, path, pathItem }: {
        value: string | number;
        objArr: {
            [x: string]: any;
        }[];
        path?: string | undefined;
        pathItem?: string | undefined;
    }): string;
    /**
     * @function
     * @description Summation function
     * @param {number} value1
     * @param {number} value2
     * @returns {number}
     */
    addValue({ value1, value2 }: {
        value1: any;
        value2: any;
    }): any;
};
export default _default;
