import { Toast } from 'vercel-toast';
declare const _default: {
    /**
     * @function
     * @description  Parse the incoming Base64 data into blobs.
     * @param {string} data
     * @param {string} type
     * @returns {string}
     */
    base64ToBlob({ data, type, }: {
        data: string;
        type: string;
    }): string | undefined;
    /**
     * @function
     * @description  Verify that the value passed in is empty
     * @param {Record<any, any>} args
     * @returns {boolean}
     */
    exists(args: Record<any, any>): boolean;
    /**
     * @function
     * @description  Print data information
     * @param {any} value
     * @returns {void}
     */
    log({ value }: {
        value: any;
    }): void;
    /**
     * @function
     * @description  Decrypt the incoming document
     * @param {Record<string, any>} doc
     * @returns {any}
     */
    prepareDoc({ doc }: {
        doc: Record<string, any>;
    }): Promise<any>;
    /**
     * @function
     * @description  Resolve the incoming doc ID into a path path and return it
     * @param {any} id
     * @returns {any}
     */
    prepareDocToPath(id: any): Promise<{
        type: any;
        url: any;
    } | undefined>;
    /**
     * @function
     * @description  Prompt pop-up effect in browser
     * @param {any} toastMessage
     * @returns {void}
     */
    toaster({ toastMessage }: {
        toastMessage: any;
    }): void;
    /**
     * @function
     * @description  Splits the incoming string into spaces and returns the first item
     * @param {string} num
     * @returns {string}
     */
    getCountryCode({ uid }: {
        uid: string;
    }): string;
    /**
     * @function
     * @description  Splits the incoming string into spaces and returns the second item
     * @param {string} num
     * @returns {string}
     */
    getPhoneNumber({ uid }: {
        uid: string;
    }): string;
    /**
     * @function
     * @description  Gets the value of the current localstorage store
     * @param {void}
     * @returns {any}
     */
    getTempParams(): any;
    /**
     * @function
     * @description  Set key value pairs for localstorage storage
     * @param {any} Object
     * @returns {any}
     */
    setTempParams({ Object }: {
        Object: any;
    }): void;
    /**
     * @function
     * @description  Set synchronization blocking delay effect
     * @param {number} timeUnix
     * @returns {void}
     */
    setTimer({ timeUnix }: {
        timeUnix: number;
    }): void;
    /**
     * @function
     * @description  Remove keys from localstorage storage
     * @param {void}
     * @returns {void}
     */
    removeTempParams(): void;
    /**
     * @function
     * @description  Remove the value stored in localstorage through the key
     * @param {string} key
     * @returns {void}
     */
    removeKeyTempParams({ key }: {
        key: any;
    }): void;
    /**
     * @function
     * @description  Get file size
     * @param {object} object
     * @param {string} units
     * @returns {number}
     */
    getFileSize({ object, units, }: {
        object: object;
        units: 'kb' | 'mb';
    }): string | 0;
    /**
     * @function
     * @description  Get file name
     * @param {object} object
     * @returns {string}
     */
    getFileName({ object }: {
        object: object;
    }): any;
    /**
     * @function
     * @description  copy to clipboard
     * @param {object} object
     * @returns {number}
     */
    copyToClip({ object }: {
        object: object;
    }): number;
    /**
     *
     * @function
     * @description set LocalStorage item
     * @param {string}key lcoalstorage key
     * @param {string}value lcoalstorage value
     * @returns {void}
     */
    setLocalStorage({ key, value }: {
        key: string;
        value: string;
    }): void;
    /**
     *
     * @function
     * @description get LocalStorage item
     * @param {string} key
     * @return {string}
     */
    getLocalStorage({ key }: {
        key: string;
    }): string | null;
    /**
     * @function
     * @description Depth assignment function
     * @param {any} data
     * @return {any}
     */
    cloneDeepData({ data }: {
        data: any;
    }): any;
    /**
     * @function
     * @description Get the URL of the current page
     * @return {string}
     */
    getUrl(): string;
    /**
     * @function
     * @description Validate input variables
     * @param {string} username
     * @return {boolean}
     */
    usernameCheck({ username }: {
        username: string;
    }): boolean;
    /**
     * @function
     * @description Judge that all values are equal
     * @param {string|number} value
     * @param {string|number} index
     * @return {boolean}
     */
    judgeAll({ value, index, }: {
        value: (string | number)[];
        index: string | number;
    }): boolean;
    /**
     * @function
     * @description Judge whether two objects are identical
     * @param {any} data
     * @param {any} comData
     * @return {boolean}
     */
    areTheyIdentical({ data, comData }: {
        data: any;
        comData: any;
    }): boolean;
    /**
     * @function
     * @description judge image
     * @param file
     * @return {boolean}
     */
    isImageFile({ file }: {
        file: string;
    }): boolean;
    /**
     * @function
     * @description Array summation
     * @param {number[]} array
     * @return {number}
     */
    addArrayValue({ array }: {
        array: any;
    }): number;
    /**
     * @function
     * @description OCR recognized as true
     * @param {any} image
     * @return {boolean}
     */
    AWSOCR({ image }: {
        image: any;
    }): {
        DATE_OF_BIRTH: string;
        FIRST_NAME: string;
        LAST_NAME: string;
        MIDDLE_NAME: string;
        CITY_IN_ADDRESS: string;
        COUNTY: string;
        ADDRESS: string;
        ADDRESS_SECOND_LINE: string;
        STATE_IN_ADDRESS: string;
        ZIP_CODE_IN_ADDRESS: string;
        DOCUMENT_NUMBER: string;
        ID_TYPE: string;
    };
    /**
     * @function
     * @description Get the hashcode of an object combination
     * @param {string[]} hashFields
     * @param {Date} hashtime
     * @return {string}
     */
    gethashCode({ hashFields, hashtime, }: {
        hashFields: string[];
        hashtime?: number | undefined;
    }): string;
    setEmpty({ variable, identifier }: {
        variable: any[];
        identifier: string;
    }): any[] | undefined;
};
export default _default;
export declare function toast(message: string | number, options?: Toast['options']): Toast | undefined;
