import type CADL from './CADL';
import populateString from '../utils/populateString';
import type { ShouldAttachRefFn } from '../types';
export { createFuncAttacher, populateKeys, populateString, populateArray, populateObject, populateVals, replaceUint8ArrayWithBase64, replaceEvalObject, replaceVars, getHandedCode, };
/**
 * Merges keys in source object with objects in locations where keys match lookFor.
 *
 * @param PopulateKeysArgs
 * @param PopulateKeysArgs.source Object to populate.
 * @param PopulateKeysArgs.lookFor Symbols to lookFor in properties e.g ['..,.']
 * @param PopulateKeysArgs.locations
 * @returns Populated object.
 */
declare function populateKeys({ source, lookFor, locations, }: {
    source: Record<string, any>;
    lookFor: string;
    locations: Record<string, any>[];
}): Record<string, any>;
/**
 * Attaches ecos functions to api objects.
 *
 * There are two kinds of API objects.
 *
 * There are objects who have an "api" property where the value is an eCOS method
 *
 * @example
 * ```
 * const apiObject = { api: 'ce', dataIn: {...}, dataOut: {...} }
 * ```
 *
 * And there are objects who are references to builtIn functions
 *
 * @example
 *
 * ```
 * const builtInReference = {
 * 	'=.builtIn.string.equal': {
 *			dataIn: {...},
 *			dataOut: {...}
 *   }
 * }
 * ```
 *
 * @param cadlObject
 * @param dispatch
 * @returns The object with functions attached to it.
 */
declare function createFuncAttacher({ cadlObject, dispatch, force, }: {
    cadlObject: Record<string, any>;
    dispatch: CADL['dispatch'];
    force?: boolean;
}): Record<string, any>;
export declare const createFuncAttacher2: ({ cadlObject, dispatch, force, }: {
    cadlObject: Record<string, any>;
    dispatch: CADL['dispatch'];
    force?: boolean | undefined;
}) => Record<string, any>;
/**
 * Replaces the eval object, if any, with a function that performs the the actions detailed in the actionType evalObject
 *
 * @param ReplaceEvalObjectArgs
 * @param ReplaceEvalObjectArgs.cadlObject
 * @param ReplaceEvalObjectArgs.dispatch
 * @returns Object with evalObject replaced by a function.
 *
 */
declare function replaceEvalObject({ pageName, cadlObject, dispatch, }: {
    pageName: string;
    cadlObject: Record<string, any>;
    dispatch: Function;
}): Promise<Record<string, any>>;
/**
 * Dereference values in an array data structure.
 *
 * @param PopulateArrayArgs
 * @param PopulateArrayArgs.source Object that has values that need to be replaced.
 * @param PopulateArrayArgs.lookFor Item to look for in object
 * @param PopulateArrayArgs.locations Array of objects that may contain the values for the source object
 * @param PopulateArrayArgs.path
 * @param PopulateArrayArgs.dispatch Function to change the state.
 * @param PopulateArrayArgs.pageName
 *
 * @returns Dereferenced array.
 */
declare function populateArray({ source, lookFor, skip, locations, path, dispatch, pageName, shouldAttachRef, skipIf, }: {
    source: any[];
    lookFor: string;
    skip?: string[];
    locations: Record<string, any>[];
    path?: string[];
    dispatch?: Function;
    pageName?: string;
    shouldAttachRef?: ShouldAttachRefFn;
    skipIf?: boolean;
}): any[];
/**
 * De-references source object by looking for items in the given locations.
 *
 * @param PopulateObjectArgs
 * @param PopulateObjectArgs.source Object that has values that need to be replaced
 * @param PopulateObjectArgs.lookFor Item to look for in object
 * @param PopulateObjectArgs.locations Array of objects that may contain the values for the source object
 * @param PopulateObjectArgs.skip
 * @param PopulateObjectArgs.path
 * @param PopulateObjectArgs.dispatch
 * @param PopulateObjectArgs.pageName
 *
 * @returns Dereferenced object
 */
declare function populateObject({ source, lookFor, locations, skip, path, dispatch, pageName, skipIf, shouldAttachRef, }: {
    source: Record<string, any>;
    lookFor: string;
    locations: Record<string, any>[];
    skip?: string[];
    path?: string[];
    dispatch?: Function;
    pageName?: string;
    skipIf?: boolean;
    shouldAttachRef?: ShouldAttachRefFn;
}): Record<string, any>;
/**
 * De-reference source object by looking for multiple items in multiple locations.
 *
 * @param PopulateValsArgs
 * @param PopulateValsArgs.source Object that needs de-referencing.
 * @param PopulateValsArgs.lookFor An array of items to look for e.g ['.','..']
 * @param PopulateValsArgs.locations Locations to look for values.
 * @param PopulateValsArgs.skip Keys to skip in the de-referencing process.
 * @param PopulateValsArgs.pageName
 * @param PopulateValsArgs.dispatch Function to alter the state.
 * @returns
 */
declare function populateVals({ source, lookFor, locations, skip, pageName, dispatch, shouldAttachRef, }: {
    source: Record<string, any> | string;
    lookFor: string[];
    skip?: string[];
    locations: any[];
    pageName?: string;
    shouldAttachRef?: ShouldAttachRefFn;
    dispatch?: Function;
}): any;
/**
 * Replaces Uint8Array values with base64 values
 *
 * @param source Object that needs values replaced.
 * @returns Object that has had Uint8Array values mapped to base64.
 */
declare function replaceUint8ArrayWithBase64(source: Record<string, any> | any[]): Record<string, any>;
declare function replaceVars({ vars, source }: {
    vars: any;
    source: any;
}): Record<string, any>;
declare function getHandedCode(_handledCode: any): any[];
